@@ -18,22 +18,17 @@ OC.L10N.register(
     "Save" : "Stoor",
     "Connect" : "Verbind",
     "Add mail account" : "Voeg posrekening toe",
-    "Keyboard shortcuts" : "Sneltoetse",
     "Subject" : "Onderwerp",
     "Sending …" : "Stuur…",
     "Go back" : "Gaan terug",
     "Retry" : "Herprobeer",
     "Message sent!" : "Boodskap gestuur!",
     "Send" : "Stuur",
-    "Favorite" : "Gunsteling",
     "Select" : "Kies",
     "Delete" : "Skrap",
     "Important" : "Belangrik",
     "Favorites" : "Gunstelinge",
     "Other" : "Ander",
-    "to" : "aan",
-    "Reply" : "Antwoord",
-    "Forward" : "Stuur aan",
     "Import into calendar" : "Voer in na kalender",
     "Download attachment" : "Laai aanhangsel af",
     "Unnamed" : "Naamloos",
@@ -41,14 +36,20 @@ OC.L10N.register(
     "Settings" : "Instellings",
     "Quota" : "Kwota",
     "Add folder" : "Voeg 'n gids by",
+    "Saving" : "Stoor tans",
     "Remove account" : "Verwyder rekening",
     "Loading …" : "Laai …",
     "Cancel" : "Kanselleer",
+    "Delete folder" : "Skrap vouer",
     "Signature" : "Handtekening",
+    "Reply" : "Antwoord",
+    "Forward" : "Stuur aan",
     "General" : "Algemeen",
     "User" : "Gebruiker",
     "Host" : "Gasheer",
     "Port" : "Poort",
+    "Keyboard shortcut" : "Snelsleutel",
+    "Keyboard shortcuts" : "Sneltoetse",
     "Search" : "Soek",
     "Refresh" : "Verfris",
     "Connect your mail account" : "Koppel u posrekening",
