@@ -1,10 +1,11 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "البريد",
     "Auto detect failed. Please use manual mode." : "فشل في عملية التحقق الآلي. الرجاء استخدام نمط الدليل.",
     "Updating account failed: " : "فشلت عملية تحديث الحساب :",
     "Creating account failed: " : "فشل في إنشاء الحساب:",
+    "Mails" : "الرسائل",
+    "Mail" : "البريد",
     "Name" : "الإسم",
     "Mail Address" : "عنوان البريد الإلكتروني",
     "Password" : "كلمة المرور",
@@ -25,7 +26,6 @@ OC.L10N.register(
     "Save" : "حفظ",
     "Connect" : "اتصال",
     "Add mail account" : "أضف حساب بريدي",
-    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
     "Select account" : "إختيار حساب",
     "Subject" : "الموضوع",
     "Upload attachment" : "رفع المرفقات",
@@ -38,19 +38,13 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
     "Choose a file to share as a link" : "اختر ملفا لمشاركته كرابط",
     "Draft: " : "المسودة:",
-    "Favorite" : "المفضلة",
     "Unselect" : "إلغاء التحديد",
     "Select" : "تحديد",
     "Delete" : "حذف",
     "Important" : "مهم",
     "Favorites" : "المفضلات",
     "Other" : "آخر",
-    "Not found" : "غير موجود",
-    "to" : "إلى",
-    "cc" : "نسخة كربونية",
-    "Reply" : "رد",
-    "Forward" : "إعادة توجيه ",
-    "Could not load your message" : "تعذرت عملية تحميل رسالتك",
+    "Attachments" : "المرفقات",
     "Import into calendar" : "إستيراد من التقويم",
     "Download attachment" : "تنزيل الملحق",
     "Save to Files" : "حفظ للـ الملفات",
@@ -62,19 +56,25 @@ OC.L10N.register(
     "Settings" : "الإعدادات",
     "Quota" : "الحصة",
     "Add folder" : "إضافة مجلد",
+    "Saving" : "جاري الحفظ ...",
     "Remove account" : "حذف حساب",
     "Cancel" : "إلغاء",
     "Show all folders" : "أظهر جميع المجلدات",
     "Collapse folders" : "طي المجلدات",
     "Mark all as read" : "تحديد الكل كمقروء",
     "Clear cache" : "مسح ذاكرة التخزين المؤقتة",
+    "Delete folder" : "حذف المجلد",
+    "Not found" : "غير موجود",
     "Signature" : "التوقيع",
+    "Reply" : "رد",
+    "Forward" : "إعادة توجيه ",
     "General" : "العامة",
     "Email address" : "عنوان البريد الإلكتروني",
     "User" : "المستخدم",
     "Host" : "المضيف",
     "Port" : "المنفذ",
     "Mail server" : "خادم البريد",
+    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
     "Speed up your Mail experience with these quick shortcuts." : "سرّع تجربة بريدك مع هذه الإختصارات.",
     "Compose new message" : "إرسل رسالة جديدة",
     "Newer message" : "الرسائل الأحدث",
@@ -96,6 +96,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "بريد ناكست كلاود",
     "Could not load {tag}{name}{endtag}" : "تعذر تحميل {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "حدث خطأ ما عند تحميل {tag}{name}{endtag}",
+    "Could not load your message" : "تعذرت عملية تحميل رسالتك",
     "Could not load the message" : "تعذرت عملية تحميل الرسالة",
     "Error loading message" : "حدث خطأ خلال تحميل الرسالة",
     "Forwarding to %s" : "تمرير إلى %s",
