@@ -1,9 +1,9 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Corréu",
     "Auto detect failed. Please use manual mode." : "Falló l'autodeteición. Por favor, usa el mou manual.",
     "Creating account failed: " : "Fallu creando la cuenta:",
+    "Mail" : "Corréu",
     "Name" : "Nome",
     "Mail Address" : "Direición de corréu",
     "Password" : "Contraseña",
@@ -20,7 +20,6 @@ OC.L10N.register(
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
     "Connect" : "Coneutar",
-    "Keyboard shortcuts" : "Atayos de tecláu",
     "Select account" : "Esbillar cuenta",
     "Subject" : "Asuntu",
     "Sending …" : "Unviando...",
@@ -29,15 +28,12 @@ OC.L10N.register(
     "Message sent!" : "¡Mensaxe unviáu!",
     "Send" : "Unviar",
     "Choose a file to add as attachment" : "Escueyi un ficheru p'amestalu como axuntu",
-    "Favorite" : "Marcar como favoritu",
     "Select" : "Esbillar",
     "Delete" : "Desaniciar",
     "Important" : "Importante",
     "Favorites" : "Favorites",
     "Other" : "Otru",
-    "to" : "hasta",
-    "Reply" : "Rempuesta",
-    "Could not load your message" : "Nun pudo cargase'l to mensaxe",
+    "Attachments" : "Axuntos",
     "Download attachment" : "Baxar axuntu",
     "Unnamed" : "Ensin nome",
     "Choose a folder to store the attachment in" : "Escueyi una carpeta pa guardar l'axuntu",
@@ -46,6 +42,7 @@ OC.L10N.register(
     "Settings" : "Axustes",
     "Quota" : "Cuota",
     "Add folder" : "Add folder",
+    "Saving" : "Guardando",
     "Remove account" : "Desaniciar cuenta",
     "Loading …" : "Cargando...",
     "Cancel" : "Encaboxar",
@@ -53,11 +50,15 @@ OC.L10N.register(
     "Collapse folders" : "Contrayer carpetes",
     "Mark all as read" : "Conseñar too como lleío",
     "Clear cache" : "Llimpiar caché",
+    "Delete folder" : "Desaniciar",
     "Signature" : "Robla",
+    "Reply" : "Rempuesta",
     "General" : "Xeneral",
     "User" : "Usuariu",
     "Host" : "Agospiu",
     "Port" : "Puertu",
+    "Keyboard shortcut" : "Atayu de tecláu",
+    "Keyboard shortcuts" : "Atayos de tecláu",
     "Search" : "Guetar",
     "Refresh" : "Refrescar",
     "All" : "Too",
@@ -72,6 +73,7 @@ OC.L10N.register(
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaxe nuevu \nde {from}","%n mensaxes nuevos \nde {from}"],
     "Could not load {tag}{name}{endtag}" : "Nun pudo cargase {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Hebo un problema cargando  {tag}{name}{endtag}",
+    "Could not load your message" : "Nun pudo cargase'l to mensaxe",
     "Error loading message" : "Fallu cargando mensaxe",
     "Forwarding to %s" : "Reunviando a %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Primi equí si nun se te redirixe de mou automáticu en próximos segundos.",
