@@ -1,9 +1,9 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Məktub",
     "Auto detect failed. Please use manual mode." : "Avtomatik təyinatda səhv baş verdi. Xahiş olunur əl rejimini seçəsiniz.",
     "Creating account failed: " : "Hesabın yaradılmasında səhv:",
+    "Mail" : "Məktub",
     "Name" : "Ad",
     "Password" : "Şifrə",
     "None" : "Heç bir",
@@ -13,14 +13,11 @@ OC.L10N.register(
     "Sending …" : "Göndərilir...",
     "Send" : "Göndər",
     "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
-    "Favorite" : "İstəkli",
     "Select" : "Select",
     "Delete" : "Sil",
     "Important" : "Vacib",
     "Favorites" : "Sevimlilər",
     "Other" : "Digər",
-    "to" : "doğru",
-    "Reply" : "Cavab",
     "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
     "Settings" : "Quraşdırmalar",
     "Quota" : "Norma",
@@ -28,6 +25,8 @@ OC.L10N.register(
     "Cancel" : "Dayandır",
     "Mark all as read" : "Hamısını oxunulmuş kimi qeydə al",
     "Clear cache" : "Keşi təmizlə",
+    "Delete folder" : "Qovluğu sil",
+    "Reply" : "Cavab",
     "General" : "Ümumi",
     "User" : "User",
     "Host" : "Şəbəkədə ünvan",
