@@ -1,9 +1,9 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Поща",
     "Auto detect failed. Please use manual mode." : "Неуспешни автоматични настройки. Моля, използвай ръчен режим.",
     "Creating account failed: " : "Неуспешно създаване на профил:",
+    "Mail" : "Поща",
     "Auto" : "Автоматично",
     "Name" : "Име",
     "Mail Address" : "Имейл адрес",
@@ -27,7 +27,6 @@ OC.L10N.register(
     "Save" : "Запис",
     "Connect" : "Свържи",
     "Add mail account" : "Добавяне на профил",
-    "Keyboard shortcuts" : "Бързи клавиши",
     "From" : "От",
     "Select account" : "Избери профил",
     "To" : "До",
@@ -49,8 +48,6 @@ OC.L10N.register(
     "Rich text" : "Форматиран текст",
     "No messages in this folder" : "Няма съобщения",
     "Draft: " : "Чернова: ",
-    "Unfavorite" : "Премахване от Любими",
-    "Favorite" : "Любима",
     "Mark unread" : "Маркирай като непрочетено",
     "Mark read" : "Маркирай като прочетено",
     "Unselect" : "Размаркирай",
@@ -60,11 +57,7 @@ OC.L10N.register(
     "Important" : "Важно",
     "Favorites" : "Любими",
     "Other" : "Друг",
-    "to" : "до",
-    "cc" : "ЯК",
-    "Reply" : "Отговори",
-    "Forward" : "Напред",
-    "Could not load your message" : "Вашето съобщение не може да бъде заредено",
+    "Attachments" : "Прикачени файлове",
     "Download attachment" : "Изтегли прикачените файлове",
     "Save to Files" : "Запази във Файлове",
     "Unnamed" : "Без име",
@@ -72,21 +65,25 @@ OC.L10N.register(
     "New message" : "Ново съобщение",
     "Settings" : "Настройки",
     "Quota" : "Квота",
-    "Edit account" : "Редактиране на профила",
+    "Account settings" : "Настройки на профила",
     "Add folder" : "Добави папка",
+    "Saving" : "Запазване",
     "Remove account" : "Изтриване",
     "Loading …" : "Зарежда …",
     "Cancel" : "Отказ",
     "Show all folders" : "Покажи всички папки",
     "Collapse folders" : "Свиване на папки",
     "Mark all as read" : "Маркирай всички като прочетени",
-    "Mark all messages of this folder as read" : "Маркирай всички съобщения в папката като прочетени",
     "Add subfolder" : "Добави подпапка",
+    "Edit name" : "Редактирай името",
     "Clear cache" : "Изтриване на кеша",
+    "Delete folder" : "Изтриване на папка",
     "No message selected" : "Не е избрано съобщение",
     "Signature" : "Подпис",
     "A signature is added to the text of new messages and replies." : "Подписът се добавя в края на текста, на изходящите съобщения.",
     "Signature …" : "Подпис…",
+    "Reply" : "Отговори",
+    "Forward" : "Напред",
     "Email: {email}" : "Имейл: {email}",
     "General" : "Общи",
     "Email address" : "Имейл адрес",
@@ -95,8 +92,9 @@ OC.L10N.register(
     "Host" : "Хост",
     "Port" : "Порт",
     "SMTP" : "SMTP",
-    "Account settings" : "Настройки на профила",
     "Mail server" : "Имейл сървър",
+    "Keyboard shortcut" : "Клавишни комбинации",
+    "Keyboard shortcuts" : "Бързи клавиши",
     "Compose new message" : "Създай ново съобщение",
     "Newer message" : "Следващо съобщение",
     "Older message" : "Предишно съобщение",
@@ -118,6 +116,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud Имейл",
     "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} не може да бъде зареден",
     "There was a problem loading {tag}{name}{endtag}" : "Проблем при зареждане на {tag}{name}{endtag}",
+    "Could not load your message" : "Вашето съобщение не може да бъде заредено",
     "Could not load the desired message" : "Желаното съобщение не може да бъде заредено",
     "Could not load the message" : "Съобщението не може да бъде заредено",
     "Error loading message" : "Грешка при зареждане съобщението",
