@@ -7,21 +7,20 @@ OC.L10N.register(
     "None" : "Ništa",
     "SMTP Password" : "SMPT Lozinka",
     "Save" : "Spremi",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
     "Send" : "Pošalji",
-    "Favorite" : "Favorit",
     "Select" : "Select",
     "Delete" : "Obriši",
     "Important" : "Važno",
     "Favorites" : "Favoriti",
     "Other" : "Ostali",
-    "to" : "do",
     "Settings" : "Podešavanje",
     "Quota" : "Kvota",
     "Add folder" : "Add folder",
     "Cancel" : "Otkaži",
+    "Delete folder" : "Izbriši fasciklu",
     "User" : "User",
     "Port" : "Priključak",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
     "Search" : "Search",
     "All" : "Sve"
 },
