@@ -1,10 +1,10 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "E-bost",
     "Auto detect failed. Please use manual mode." : "Methodd awtoganfod. Defnyddiwch y modd llaw.",
     "Updating account failed: " : "Methodd diweddaru'r cyfrif :",
     "Creating account failed: " : "Methodd creu'r cyfrif:",
+    "Mail" : "E-bost",
     "Auto" : "Awto",
     "Name" : "Enw",
     "Mail Address" : "Cyfeiriad E-bost",
@@ -29,13 +29,12 @@ OC.L10N.register(
     "Connect" : "Cysylltu",
     "Add mail account" : "Ychwanegu cyfrif post",
     "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon",
-    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
-    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Chwilio am ffordd i amgryptio'ch e-byst? Gosodwch estyniad porwr Mailvelope!",
     "Subject" : "Pwnc",
     "Saving draft …" : "Yn cadw drafft …",
     "Draft saved" : "Cadwyd y drafft",
     "Upload attachment" : "Llwytho atodiad",
     "Add attachment from Files" : "Ychwanegwch atodiad o'r Ffeiliau",
+    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Chwilio am ffordd i amgryptio'ch e-byst? Gosodwch estyniad porwr Mailvelope!",
     "Uploading attachments …" : "Llwytho atodiadau ...",
     "Sending …" : "Anfon",
     "Error sending your message" : "Gwall wrth anfon eich neges",
@@ -48,16 +47,14 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
     "No messages in this folder" : "Dim negeseuon yn y ffolder hon",
     "Draft: " : "Drafft:",
-    "Favorite" : "Ffefryn",
-    "Mark read" : "Marcio wedi'i ddarllen",
     "Mark unread" : "Nodi heb ei ddarllen",
+    "Mark read" : "Marcio wedi'i ddarllen",
+    "Select" : "Select",
     "Delete" : "Dileu",
     "Report this bug" : "Cofnodi'r gwall",
     "Loading messages" : "Llwytho negeseuon",
-    "Not found" : "Heb ei ganfod",
-    "to" : "at",
-    "cc" : "cc",
-    "Could not load your message" : "Methu llwytho'ch neges",
+    "Favorites" : "Ffefrynnau",
+    "Other" : "Arall",
     "Import into calendar" : "Mewnforio i'r calendr",
     "Download attachment" : "Llwytho'r atodiad i lawr",
     "Save to Files" : "Cadw i Ffeiliau",
@@ -65,23 +62,23 @@ OC.L10N.register(
     "Save all to Files" : "Cadw'r cyfan i Ffeiliau",
     "Choose a folder to store the attachments in" : "Dewiswch ffolder i gadw'r atodiadau ynddi",
     "The images have been blocked to protect your privacy." : "Mae'r delweddau wedi'u rhwystro i ddiogelu eich preifatrwydd.",
-    "Show images from this\tsender" : "Dangoswch ddelweddau o'r \tanfonwr hwn",
     "New message" : "Neges newydd",
     "Settings" : "Gosodiadau",
     "Add folder" : "Ychwanegu ffolder",
-    "Delete account" : "Delete account",
+    "Loading …" : "Yn llwytho …",
+    "Cancel" : "Diddymu",
     "Show all folders" : "Dangos pob ffolder",
     "Collapse folders" : "Cwympo ffolderi",
     "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
-    "Mark all messages of this folder as read" : "Marcio'r holl negeseuon y ffolder hon fel y'u darllenwyd",
     "Add subfolder" : "Ychwanegu is-ffolder",
-    "Loading …" : "Yn llwytho …",
+    "Not found" : "Heb ei ganfod",
     "Could not load your draft" : "Methu llwytho eich drafft",
     "No message selected" : "Dim neges wedi'i dewis",
     "Signature" : "Llofnod",
     "General" : "Cyffredinol",
     "User" : "User",
     "Mail server" : "Gweinydd e-bost",
+    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
     "Speed up your Mail experience with these quick shortcuts." : "Cyflymwch eich profiad E-bost gyda'r llwybrau byr cyflym hyn.",
     "Compose new message" : "Ysgrifennu Neges _Newydd",
     "Newer message" : "Neges diweddarach",
@@ -94,7 +91,6 @@ OC.L10N.register(
     "All" : "Popeth",
     "Archive" : "Archif",
     "Drafts" : "Drafftiau",
-    "Favorites" : "Ffefrynnau",
     "All inboxes" : "Pob blwch derbyn",
     "Inbox" : "Blwch Derbyn",
     "Junk" : "Sothach",
@@ -105,6 +101,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "E-bost Nextcloud",
     "Could not load {tag}{name}{endtag}" : "Methu llwytho {tag} {name} {endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Bu anhawster wrth lwytho {tag}{name}{endtag}",
+    "Could not load your message" : "Methu llwytho'ch neges",
     "Could not load the desired message" : "Methu llwytho'r neges a ddewiswyd",
     "Could not load the message" : "Methu llwytho'r neges",
     "Error loading message" : "Gwall wrth lwytho neges",
