@@ -1,11 +1,12 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Mail",
     "Auto detect failed. Please use manual mode." : "Fejl ved autodetektion. Anvend venligst manuel opsætning",
     "Updating account failed: " : "Kontoen blev ikke opdateret:",
     "Creating account failed: " : "Oprettelse af konto mislykkedes:",
     "Embedded message %s" : "Indlejret besked %s",
+    "Mails" : "Mails",
+    "Mail" : "Mail",
     "💌 A mail app for Nextcloud" : "💌 En mail app til Nextcloud",
     "Auto" : "Auto",
     "Name" : "Navn",
@@ -32,7 +33,6 @@ OC.L10N.register(
     "Add mail account" : "Tilføj mail konto",
     "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
     "Register as application for mail links" : "Registrer som program til at åbne mail links",
-    "Keyboard shortcuts" : "Tastaturgenveje",
     "From" : "Fra",
     "Select account" : "Vælg konto",
     "To" : "Til",
@@ -69,8 +69,6 @@ OC.L10N.register(
     "No messages in this folder" : "Ingen beskeder i denne mappe",
     "No messages" : "Ingen beskeder",
     "Draft: " : "Kladde:",
-    "Unfavorite" : "U-favorit",
-    "Favorite" : "Foretrukken",
     "Mark unread" : "Marker som ulæst",
     "Mark read" : "Marker som læst",
     "Unselect" : "Fravælg",
@@ -80,14 +78,7 @@ OC.L10N.register(
     "Important" : "Vigtigt",
     "Favorites" : "Favoritter",
     "Other" : "Andet",
-    "Not found" : "Ikke fundet",
-    "to" : "til",
-    "cc" : "cc",
-    "Reply" : "Besvar",
-    "Forward" : "Videresend",
-    "View source" : "Vis kildekode",
-    "Message source" : "Beskedens kildekode",
-    "Could not load your message" : "Din besked kunne ikke indlæses",
+    "Attachments" : "Vedhæftede filer",
     "Import into calendar" : "Importere til kalender",
     "Download attachment" : "Hent vedhæftning",
     "Save to Files" : "Gem til filer",
@@ -101,9 +92,9 @@ OC.L10N.register(
     "New message" : "Ny besked",
     "Settings" : "Indstillinger",
     "Quota" : "Kvote",
-    "Edit account" : "Rediger konto",
+    "Account settings" : "Kontoindstillinger",
     "Add folder" : "Tilføj mappe",
-    "Move Up" : "Flyt op",
+    "Saving" : "Gemmer",
     "Move down" : "Flyt ned",
     "Remove account" : "Fjern konto",
     "Loading …" : "Indlæser…",
@@ -111,14 +102,20 @@ OC.L10N.register(
     "Show all folders" : "Vis alle mapper",
     "Collapse folders" : "Fold mapper sammen",
     "Mark all as read" : "Markér alle som læst",
-    "Mark all messages of this folder as read" : "Markér alle beskeder i denne mappe som læst",
     "Add subfolder" : "Tilføj undermappe",
+    "Edit name" : "Rediger navn",
     "Clear cache" : "Ryd cache",
+    "Delete folder" : "Slet mappe",
     "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
+    "Not found" : "Ikke fundet",
     "Could not load your draft" : "Kladden kunne ikke indlæses",
     "Could not load original message" : "Den originale besked kunne ikke indlæses",
     "No message selected" : "Ingen besked valgt",
     "Signature" : "Underskrift",
+    "Reply" : "Besvar",
+    "Forward" : "Videresend",
+    "View source" : "Vis kildekode",
+    "Message source" : "Beskedens kildekode",
     "Airplane" : "Fly",
     "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
     "Train" : "Tog",
@@ -131,7 +128,8 @@ OC.L10N.register(
     "Host" : "Vært",
     "Port" : "Port",
     "SMTP" : "SMTP",
-    "Account settings" : "Kontoindstillinger",
+    "Keyboard shortcut" : "Tastaturgenvej",
+    "Keyboard shortcuts" : "Tastaturgenveje",
     "Speed up your Mail experience with these quick shortcuts." : "Gør brugen af Mail hurtige med disse genveje.",
     "Compose new message" : "Skriv en ny meddelelse",
     "Newer message" : "Nyere besked",
@@ -157,6 +155,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud Mail",
     "Could not load {tag}{name}{endtag}" : "Kunne ikke hente {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Der var et problem med at hente {tag}{name}{endtag}",
+    "Could not load your message" : "Din besked kunne ikke indlæses",
     "Could not load the desired message" : "Den ønskede besked kunne ikke indlæses",
     "Could not load the message" : "Beskeden kunne ikke indlæses",
     "Error loading message" : "Fejl under indlæsning af besked",
