@@ -1,10 +1,10 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Mail",
     "Auto detect failed. Please use manual mode." : "Auto detect failed. Please use manual mode.",
     "Updating account failed: " : "Updating account failed: ",
     "Creating account failed: " : "Creating account failed: ",
+    "Mail" : "Mail",
     "Name" : "Name",
     "Mail Address" : "Mail Address",
     "Password" : "Password",
@@ -23,7 +23,6 @@ OC.L10N.register(
     "Connect" : "Connect",
     "Add mail account" : "Add mail account",
     "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
-    "Keyboard shortcuts" : "Keyboard shortcuts",
     "Select account" : "Select account",
     "Subject" : "Subject",
     "Upload attachment" : "Upload attachment",
@@ -35,20 +34,14 @@ OC.L10N.register(
     "Send" : "Send",
     "Choose a file to add as attachment" : "Choose a file to add as attachment",
     "No messages in this folder" : "No messages in this folder",
-    "Unfavorite" : "Unfavourite",
-    "Favorite" : "Favourite",
     "Mark read" : "Mark read",
+    "Unselect" : "Unselect",
     "Select" : "Select",
     "Delete" : "Delete",
     "Important" : "Important",
     "Favorites" : "Favourites",
     "Other" : "Other",
-    "Not found" : "Not found",
-    "to" : "to",
-    "cc" : "cc",
-    "Reply" : "Reply",
-    "Forward" : "Forward",
-    "Could not load your message" : "Could not load your message",
+    "Attachments" : "Attachments",
     "Import into calendar" : "Import into calendar",
     "Download attachment" : "Download attachment",
     "Save to Files" : "Save to Files",
@@ -61,17 +54,25 @@ OC.L10N.register(
     "Settings" : "Settings",
     "Quota" : "Quota",
     "Add folder" : "Add folder",
+    "Saving" : "Saving",
     "Remove account" : "Remove account",
     "Cancel" : "Cancel",
     "Show all folders" : "Show all folders",
     "Collapse folders" : "Collapse folders",
     "Mark all as read" : "Mark all as read",
     "Clear cache" : "Clear cache",
+    "Delete folder" : "Delete folder",
+    "Not found" : "Not found",
     "Signature" : "Signature",
+    "Reply" : "Reply",
+    "Forward" : "Forward",
     "General" : "General",
     "User" : "User",
     "Host" : "Host",
     "Port" : "Port",
+    "Change name" : "Change name",
+    "Keyboard shortcut" : "Keyboard shortcut",
+    "Keyboard shortcuts" : "Keyboard shortcuts",
     "Speed up your Mail experience with these quick shortcuts." : "Speed up your Mail experience with these quick shortcuts.",
     "Compose new message" : "Compose new message",
     "Newer message" : "Newer message",
@@ -94,6 +95,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud Mail",
     "Could not load {tag}{name}{endtag}" : "Could not load {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "There was a problem loading {tag}{name}{endtag}",
+    "Could not load your message" : "Could not load your message",
     "Could not load the desired message" : "Could not load the desired message",
     "Could not load the message" : "Could not load the message",
     "Error loading message" : "Error loading message",
