@@ -1,11 +1,12 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Retpoŝtilo",
     "Auto detect failed. Please use manual mode." : "Aŭtomata rekono malsukcesis. Bv. uzi permanan reĝimon.",
     "Updating account failed: " : "Ĝisdatigo de konto malsukcesis:",
     "Creating account failed: " : "Kreo de konto malsukcesis:",
     "Embedded message %s" : "Enkorpiga mesaĝo %s",
+    "Mails" : "Retpoŝtoj",
+    "Mail" : "Retpoŝtilo",
     "💌 A mail app for Nextcloud" : "Poŝtprogrameto por Nextcloud",
     "Auto" : "Aŭtomate",
     "Name" : "Nomo",
@@ -32,7 +33,6 @@ OC.L10N.register(
     "Add mail account" : "Aldoni retpoŝtan konton",
     "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
     "Register as application for mail links" : "Registriĝi kiel programeto por retpoŝtligiloj",
-    "Keyboard shortcuts" : "Fulmoklavoj",
     "From" : "De",
     "Select account" : "Elekti konton",
     "To" : "Al",
@@ -63,8 +63,6 @@ OC.L10N.register(
     "Plain text" : "Ebenaĵa teksto",
     "No messages in this folder" : "Neniu mesaĝo en tiu dosierujo",
     "Draft: " : "Malneto:",
-    "Unfavorite" : "Malpliŝatati",
-    "Favorite" : "Pliŝatati",
     "Mark unread" : "Marki kiel nelegita",
     "Mark read" : "Marki kiel legita",
     "Unselect" : "Malelekti",
@@ -78,13 +76,7 @@ OC.L10N.register(
     "Important" : "Grava",
     "Favorites" : "Pliŝataĵoj",
     "Other" : "Alia",
-    "Not found" : "Ne trovita",
-    "to" : "al",
-    "cc" : "kopio",
-    "Reply" : "Respondi",
-    "Reply to sender only" : "Respondi nur al sendinto",
-    "Forward" : "Antaŭen",
-    "Could not load your message" : "Ne eblis ŝargi vian mesaĝon",
+    "Attachments" : "Dosieraj aldonaĵoj",
     "Import into calendar" : "Importi en kalendaron",
     "Download attachment" : "Elŝuti kunsendaĵon",
     "Save to Files" : "Konservi en „Dosieroj“",
@@ -97,9 +89,9 @@ OC.L10N.register(
     "New message" : "Nova mesaĝo",
     "Settings" : "Agordoj",
     "Quota" : "Kvoto",
-    "Edit account" : "Redakti konton",
+    "Account settings" : "Kontaj agordoj",
     "Add folder" : "Aldoni dosierujon",
-    "Move Up" : "Movi supren",
+    "Saving" : "Konservado",
     "Move down" : "Movi malsupren",
     "Remove account" : "Forigi konton",
     "Loading …" : "Ŝargas …",
@@ -107,10 +99,11 @@ OC.L10N.register(
     "Show all folders" : "Montri ĉiujn dosierujojn",
     "Collapse folders" : "Maletendi dosierujojn",
     "Mark all as read" : "Marki ĉion kiel legita",
-    "Mark all messages of this folder as read" : "Marki ĉiujn mesaĝojn el tiu dosierujo kiel legitaj",
     "Add subfolder" : "Aldoni subdosierujon",
     "Clear cache" : "Forviŝi la kaŝmemoron",
+    "Delete folder" : "Forigi dosierujon",
     "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
+    "Not found" : "Ne trovita",
     "Could not load your draft" : "Ne eblis ŝargi vian malneton",
     "Could not load original message" : "Ne eblis ŝargi originalan mesaĝon",
     "No message selected" : "Neniu mesaĝo elektita",
@@ -118,6 +111,9 @@ OC.L10N.register(
     "A signature is added to the text of new messages and replies." : "Subskribo aldonus al la teksto de novaj mesaĝoj kaj respondoj.",
     "Signature …" : "Subskribo …",
     "Save signature" : "Konservi subskribon",
+    "Reply" : "Respondi",
+    "Reply to sender only" : "Respondi nur al sendinto",
+    "Forward" : "Antaŭen",
     "Import into {calendar}" : "Importi en {calendar}",
     "Event imported into {calendar}" : "Okazaĵo importis en {calendar}",
     "Could not create event" : "Ne eblis krei okazaĵon",
@@ -137,9 +133,9 @@ OC.L10N.register(
     "Port" : "Pordo",
     "SMTP" : "SMTP",
     "Apply and create/update for all users" : "Apliki kaj krei/ĝisdatigi por ĉiuj uzantoj",
-    "Account settings" : "Kontaj agordoj",
     "Change name" : "Ŝanĝi nomon",
     "Mail server" : "Retpoŝtoservilo",
+    "Keyboard shortcuts" : "Fulmoklavoj",
     "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
     "Compose new message" : "Krei novan mesaĝon",
     "Newer message" : "Pli nova mesaĝo",
@@ -162,6 +158,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud-retpoŝtilo",
     "Could not load {tag}{name}{endtag}" : "Ne eblis ŝargi {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Problemo okazis dum ŝargi {tag}{name}{endtag}",
+    "Could not load your message" : "Ne eblis ŝargi vian mesaĝon",
     "Could not load the desired message" : "Ne eblis ŝargi la deziratan mesaĝon",
     "Could not load the message" : "Ne eblis ŝargi la mesaĝon",
     "Error loading message" : "Eraris ŝargi mesaĝon",
