@@ -1,9 +1,9 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Correo",
     "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
     "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
+    "Mail" : "Correo",
     "Name" : "Nombre",
     "Mail Address" : "Dirección de Correo",
     "Password" : "Contraseña",
@@ -22,7 +22,6 @@ OC.L10N.register(
     "Connect" : "Conectar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
-    "Keyboard shortcuts" : "Atajos del teclado",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
@@ -33,14 +32,12 @@ OC.L10N.register(
     "Message sent!" : "¡Mensaje enviado!",
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
-    "Unfavorite" : "Quitar favorito",
-    "Favorite" : "Hacer favorito",
     "Mark read" : "Marcar como leído",
+    "Select" : "Seleccionar",
     "Delete" : "Borrar",
-    "to" : "para",
-    "cc" : "cc",
-    "Reply" : "Responder",
-    "Forward" : "Reenviar",
+    "Important" : "Importante",
+    "Favorites" : "Favoritos",
+    "Other" : "Otro",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
@@ -48,18 +45,28 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
+    "Show images from this sender" : "Mostrar imagenes de este remitente",
     "New message" : "Mensaje nuevo",
     "Settings" : "Configuraciones ",
+    "Quota" : "Cuota",
     "Add folder" : "Add folder",
-    "Delete account" : "Borrar cuenta",
+    "Saving" : "Guardando",
+    "Remove account" : "Eliminar cuenta",
+    "Cancel" : "Cancelar",
     "Show all folders" : "Mostrar todas las carpetas",
     "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
+    "Clear cache" : "Borrar el caché",
+    "Delete folder" : "Borrar carpeta",
     "Signature" : "Firma",
+    "Reply" : "Responder",
+    "Forward" : "Reenviar",
     "General" : "General",
     "User" : "Ususario",
     "Host" : "Servidor",
     "Port" : "Puerto",
+    "Keyboard shortcut" : "Atajo del teclado",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -72,7 +79,6 @@ OC.L10N.register(
     "All" : "Todos",
     "Archive" : "Archivar",
     "Drafts" : "Borradores",
-    "Favorites" : "Favoritos",
     "All inboxes" : "Todos los buzones de entrada",
     "Inbox" : "Buzón de entrada",
     "Junk" : "Basura",
