@@ -1,10 +1,10 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Correo",
     "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Favor de usar el modo manual.",
     "Updating account failed: " : "Error al actualizar la cuenta:",
     "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
+    "Mail" : "Correo",
     "Name" : "Nombre",
     "Mail Address" : "Dirección de Correo",
     "Password" : "Contraseña",
@@ -22,7 +22,6 @@ OC.L10N.register(
     "Save" : "Guardar",
     "Connect" : "Conectar",
     "Add mail account" : "Agregar cuenta de correo",
-    "Keyboard shortcuts" : "Atajos de teclado",
     "Select account" : "Seleccione la cuenta",
     "Subject" : "Asunto",
     "Add attachment from Files" : "Agregar adjunto desde Archivos",
@@ -32,18 +31,13 @@ OC.L10N.register(
     "Message sent!" : "¡Mensaje enviado!",
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
-    "Favorite" : "Favorito",
     "Mark read" : "Marcar como leído",
     "Select" : "Seleccionar",
     "Delete" : "Borrar",
     "Important" : "Importante",
     "Favorites" : "Favoritos",
     "Other" : "Otro",
-    "to" : "para",
-    "cc" : "cc",
-    "Reply" : "Responder",
-    "Forward" : "Reenviar",
-    "Could not load your message" : "No se pudo cargar tu mensaje",
+    "Attachments" : "Adjuntos",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
@@ -56,17 +50,25 @@ OC.L10N.register(
     "Settings" : "Configuraciones ",
     "Quota" : "Cuota",
     "Add folder" : "Agregar carpeta",
+    "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
     "Cancel" : "Cancelar",
     "Show all folders" : "Mostrar todos las carpetas",
     "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
+    "Edit name" : "Editar nombre",
     "Clear cache" : "Limpiar caché",
+    "Delete folder" : "Borrar carpeta",
     "Signature" : "Firma",
+    "Reply" : "Responder",
+    "Forward" : "Reenviar",
     "General" : "General",
     "User" : "Usuario",
     "Host" : "Servidor",
     "Port" : "Puerto",
+    "Change name" : "Cambiar nombre",
+    "Keyboard shortcut" : "Atajo del teclado",
+    "Keyboard shortcuts" : "Atajos de teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de correo con estos atajos rápidos.",
     "Compose new message" : "Redactar nuevo mensaje",
     "Newer message" : "Mensaje mas nuevo",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Correo de Nextcloud",
     "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
+    "Could not load your message" : "No se pudo cargar tu mensaje",
     "Could not load the desired message" : "No se pudo cargar el mensaje deseado",
     "Could not load the message" : "No se pudo cargar el mensaje.",
     "Error loading message" : "Se presentó un error al cargar el mensaje",
