@@ -1,10 +1,10 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Correo",
     "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
     "Updating account failed: " : "Se presentó una falla al actualizar la cuenta",
     "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
+    "Mail" : "Correo",
     "Name" : "Nombre",
     "Mail Address" : "Dirección de Correo",
     "Password" : "Contraseña",
@@ -23,7 +23,6 @@ OC.L10N.register(
     "Connect" : "Conectar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
-    "Keyboard shortcuts" : "Atajos del teclado",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
@@ -35,19 +34,13 @@ OC.L10N.register(
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "No messages in this folder" : "No hay mensajes en esta carpeta",
-    "Unfavorite" : "Quitar favorito",
-    "Favorite" : "Hacer favorito",
     "Mark read" : "Marcar como leído",
     "Select" : "Seleccionar",
     "Delete" : "Borrar",
     "Important" : "Importante",
     "Favorites" : "Favoritos",
     "Other" : "Otro",
-    "to" : "para",
-    "cc" : "cc",
-    "Reply" : "Responder",
-    "Forward" : "Adelante",
-    "Could not load your message" : "No fue posible cargar tu mensaje",
+    "Attachments" : "Adjuntos",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
@@ -60,17 +53,23 @@ OC.L10N.register(
     "Settings" : "Configuraciones ",
     "Quota" : "Cuota",
     "Add folder" : "Agregar carpeta",
+    "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
     "Cancel" : "Cancelar",
     "Show all folders" : "Mostrar todas las carpetas",
     "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Clear cache" : "Borrar el caché",
+    "Delete folder" : "Borrar carpeta",
     "Signature" : "Firma",
+    "Reply" : "Responder",
+    "Forward" : "Adelante",
     "General" : "General",
     "User" : "Usuario",
     "Host" : "Servidor",
     "Port" : "Puerto",
+    "Keyboard shortcut" : "Atajo del teclado",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -93,6 +92,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Correo Nextcloud",
     "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
+    "Could not load your message" : "No fue posible cargar tu mensaje",
     "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
     "Could not load the message" : "No fue posible cargar el mensaje",
     "Error loading message" : "Se presentó un error al cargar el mensaje",
