@@ -1,9 +1,9 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Kirjad",
     "Auto detect failed. Please use manual mode." : "Automaatne tuvastus ebaõnnestus. Palun proovi käsitsi.",
     "Creating account failed: " : "Konto loomine ebaõnnestus:",
+    "Mail" : "Kirjad",
     "Name" : "Nimi",
     "Mail Address" : "E-posti aadress",
     "Password" : "Parool",
@@ -20,7 +20,6 @@ OC.L10N.register(
     "SMTP Password" : "SMTP parool",
     "Save" : "Salvesta",
     "Connect" : "Ühenda",
-    "Keyboard shortcuts" : "Klaviatuuri otseteed",
     "Subject" : "Teema",
     "Sending …" : "Saadan ...",
     "Go back" : "Mine tagasi",
@@ -28,33 +27,35 @@ OC.L10N.register(
     "Message sent!" : "Sõnum on saadetud!",
     "Send" : "Saada",
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
-    "Favorite" : "Lemmik",
     "Mark read" : "Märgi loetuks",
     "Select" : "Vali",
     "Delete" : "Kustuta",
     "Important" : "Tähtis",
     "Favorites" : "Lemmikud",
     "Other" : "Muu",
-    "to" : "saaja",
-    "cc" : "cc",
-    "Reply" : "Vasta",
-    "Forward" : "Edasi",
     "Unnamed" : "Nimeta",
     "Choose a folder to store the attachment in" : "Vali kaust, kuhu manus salvestada",
     "New message" : "Uus sõnum",
     "Settings" : "Seaded",
     "Quota" : "Kvoot",
     "Add folder" : "Add folder",
+    "Saving" : "Salvestamine",
     "Remove account" : "Eemalda konto",
     "Cancel" : "Loobu",
     "Show all folders" : "Näita kõiki kaustu",
     "Mark all as read" : "Märgi loetuks",
+    "Edit name" : "Muuda nime",
     "Clear cache" : "Tühjenda puhver",
+    "Delete folder" : "Kustuta kaust",
     "Signature" : "Allkiri",
+    "Reply" : "Vasta",
+    "Forward" : "Edasi",
     "General" : "Üldine",
     "User" : "Kasutaja",
     "Host" : "Host",
     "Port" : "Port",
+    "Keyboard shortcut" : "Klaviatuuri otsetee",
+    "Keyboard shortcuts" : "Klaviatuuri otseteed",
     "Search" : "Otsi",
     "Refresh" : "Värskenda",
     "All" : "Kõik",
