@@ -1,11 +1,13 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Sähköposti",
     "Auto detect failed. Please use manual mode." : "Automaattinen havaitseminen epäonnistui. Käytä manuaalitilaa.",
     "Updating account failed: " : "Tilin päivittäminen epäonnistui:",
     "Creating account failed: " : "Tilin luominen epäonnistui:",
     "Embedded message %s" : "Upotettu viesti %s",
+    "Important mail" : "Tärkeä sähköposti",
+    "Mails" : "Sähköpostit",
+    "Mail" : "Sähköposti",
     "💌 A mail app for Nextcloud" : "💌 Sähköpostisovellus Nextcloudille",
     "Auto" : "Automaattinen",
     "Name" : "Nimi",
@@ -29,10 +31,12 @@ OC.L10N.register(
     "SMTP Password" : "SMTP-salasana",
     "Save" : "Tallenna",
     "Connect" : "Yhdistä",
+    "Add alias" : "Lisää alias",
     "Add mail account" : "Lisää sähköpostitili",
     "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
     "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
-    "Keyboard shortcuts" : "Pikanäppäimet",
+    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
     "From" : "Lähettäjä",
     "Select account" : "Valitse tili",
     "To" : "Vastaanottaja",
@@ -41,6 +45,7 @@ OC.L10N.register(
     "Subject" : "Aihe",
     "Subject …" : "Aihe…",
     "This message came from a noreply address so your reply will probably not be read." : "Tämä viesti saapui noreply-osoitteesta, joten vastaustasi ei luultavasti lueta.",
+    "The following recipients do not have a PGP key: {recipients}." : "Seuraavilla vastaanottajilla ei ole PGP-avainta: {recipients}.",
     "Write message …" : "Kirjoita viesti…",
     "Saving draft …" : "Tallennetaan luonnosta…",
     "Draft saved" : "Luonnos tallennettu",
@@ -48,6 +53,7 @@ OC.L10N.register(
     "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
     "Add attachment link from Files" : "Lisää liitelinkki tiedostosovelluksesta",
     "Enable formatting" : "Käytä muotoilua",
+    "Encrypt message with Mailvelope" : "Salaa viesti Mailvelopella",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Etsitkö tapaa salata sähköpostisi? Asenna Mailvelope-selainlaajennus!",
     "Uploading attachments …" : "Lähetetään liitteitä…",
     "Sending …" : "Lähetetään…",
@@ -57,21 +63,31 @@ OC.L10N.register(
     "Message sent!" : "Viesti lähetetty!",
     "Write another message" : "Kirjoita toinen viesti",
     "Send" : "Lähetä",
+    "Encrypt and send" : "Salaa ja lähetä",
+    "Send unencrypted" : "Lähetä salaamattomana",
     "Uploading {percent}% …" : "Lähetetään {percent}% …",
     "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
     "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
     "Writing mode" : "Kirjoitustila",
     "Preferred writing mode for new messages and replies." : "Ensisijainen kirjoitustila uusissa viesteissä ja vastauksissa.",
+    "Plain text" : "Raakateksti",
     "No messages in this folder" : "Tässä kansiossa ei ole viestejä",
+    "No messages" : "Ei viestejä",
     "Draft: " : "Luonnos: ",
-    "Unfavorite" : "Poista suosikeista",
-    "Favorite" : "Suosikki",
+    "Mark important" : "Merkitse tärkeäksi",
+    "Mark favorite" : "Merkitse suosikiksi",
     "Mark unread" : "Merkitse lukemattomaksi",
     "Mark read" : "Merkitse luetuksi",
+    "Mark as spam" : "Merkitse roskapostiksi",
     "Unselect" : "Poista valinta",
     "Select" : "Valitse",
     "Delete" : "Poista",
     "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
+    "Unfavorite " : "Ei suosikki",
+    "Favorite " : "Suosikki",
+    "Unselect " : "Ei valintaa",
+    "Delete " : "Poista",
+    "Load more" : "Lataa lisää",
     "Report this bug" : "Ilmoita viasta",
     "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
     "Loading messages" : "Ladataan viestejä",
@@ -79,15 +95,7 @@ OC.L10N.register(
     "Important" : "Tärkeä",
     "Favorites" : "Suosikit",
     "Other" : "Muu",
-    "Not found" : "Ei löytynyt",
-    "to" : "Vastaanottaja",
-    "cc" : "Kopio",
-    "Reply" : "Vastaa",
-    "Reply to sender only" : "Vastaa vain lähettäjälle",
-    "Forward" : "Lähetä edelleen",
-    "View source" : "Näytä lähde",
-    "Message source" : "Viestin lähde",
-    "Could not load your message" : "Viestiä ei voitu ladata",
+    "Attachments" : "Liitteet",
     "Import into calendar" : "Tuo kalenteriin",
     "Download attachment" : "Lataa liite",
     "Save to Files" : "Tallenna tiedostoihin",
@@ -96,25 +104,40 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
     "Save all to Files" : "Tallenna kaikki tiedostoihin",
     "Choose a folder to store the attachments in" : "Valitse kansio johon liitteet tallennetaan",
+    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Tämä viesti on salattu PGP:llä. Asenna Mailvelope purkaaksesi viestin salauksen.",
     "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
     "Show images from this sender" : "Näytä kuvat tältä lähettäjältä",
     "New message" : "Uusi viesti",
     "Settings" : "Asetukset",
     "Quota" : "Kiintiö",
-    "Edit account" : "Muokkaa tiliä",
+    "Account settings" : "Tilin asetukset",
+    "Show only subscribed folders" : "Näytä vain tilatut kansiot",
     "Add folder" : "Lisää kansio",
-    "Move Up" : "Siirrä ylös",
+    "Saving" : "Tallennetaan",
+    "Move up" : "Siirrä ylös",
     "Move down" : "Siirrä alas",
     "Remove account" : "Poista tili",
     "Loading …" : "Ladataan…",
+    "Not supported by the server" : "Ei tuettu palvelimen toimesta",
+    "{usage} of {limit} used" : "{usage}/{limit} käytetty",
+    "Remove account {email}" : "Poista tili {email}",
+    "Remove {email}" : "Poista {email}",
     "Cancel" : "Peruuta",
+    "Show all subscribed folders" : "Näytä kaikki tilatut kansiot",
     "Show all folders" : "Näytä kaikki kansiot",
     "Collapse folders" : "Supista kansiot",
     "Mark all as read" : "Merkitse kaikki luetuiksi",
-    "Mark all messages of this folder as read" : "Merkitse tämän kansion kaikki viestit luetuiksi",
+    "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
     "Add subfolder" : "Lisää alikansio",
+    "Edit name" : "Muokkaa nimeä",
     "Clear cache" : "Tyhjennä välimuisti",
+    "Subscribed" : "Tilattu",
+    "Delete folder" : "Poista kansio",
+    "The folder and all messages in it will be deleted." : "Tämä kansio ja kaikki sen viestit poistetaan.",
+    "Delete folder {name}" : "Poista kansio {name}",
+    "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
     "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
+    "Not found" : "Ei löytynyt",
     "Could not load your draft" : "Luonnosta ei voitu ladata",
     "Could not load original message" : "Alkuperäistä viestiä ei voitu ladata",
     "No message selected" : "Viestiä ei ole valittu",
@@ -122,6 +145,12 @@ OC.L10N.register(
     "A signature is added to the text of new messages and replies." : "Allekirjoitus lisätään uusien viestien ja vastausten tekstiosaan.",
     "Signature …" : "Allekirjoitus…",
     "Save signature" : "Tallenna allekirjoitus",
+    "Could not load your message thread" : "Viestiketjua ei voitu ladata",
+    "Reply" : "Vastaa",
+    "Reply to sender only" : "Vastaa vain lähettäjälle",
+    "Forward" : "Lähetä edelleen",
+    "View source" : "Näytä lähde",
+    "Message source" : "Viestin lähde",
     "Import into {calendar}" : "Tuo kalenteriin {calendar}",
     "Event imported into {calendar}" : "Tapahtuma tuotiin kalenteriin {calendar}",
     "Could not create event" : "Tapahtumaa ei voitu luoda",
@@ -143,9 +172,11 @@ OC.L10N.register(
     "SMTP" : "SMTP",
     "Apply and create/update for all users" : "Toteuta ja luo/päivitä kaikille käyttäjille",
     "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
-    "Account settings" : "Tilin asetukset",
     "Change name" : "Vaihda nimi",
     "Mail server" : "Sähköpostipalvelin",
+    "Set up an account" : "Määritä tili",
+    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
+    "Keyboard shortcuts" : "Pikanäppäimet",
     "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
     "Compose new message" : "Uusi viesti",
     "Newer message" : "Uudempi",
@@ -170,6 +201,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud-sähköposti",
     "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ei voitu ladata",
     "There was a problem loading {tag}{name}{endtag}" : "Ladattaessa {tag}{name}{endtag} ilmeni ongelma",
+    "Could not load your message" : "Viestiä ei voitu ladata",
     "Could not load the desired message" : "Haluttua viestiä ei voitu ladata",
     "Could not load the message" : "Viestiä ei voitu ladata",
     "Error loading message" : "Virhe viestiä ladatessa",
