@@ -10,31 +10,38 @@ OC.L10N.register(
     "SMTP Password" : "Contrasigno SMTP",
     "Save" : "Salveguardar",
     "Connect" : "Connecter se",
-    "Keyboard shortcuts" : "Combinationes de claves",
     "Sending …" : "Inviante ...",
     "Go back" : "Retornar",
     "Message sent!" : "Message inviate!",
     "Send" : "Inviar",
     "Choose a file to add as attachment" : "Selectiona un file pro adder como attachamento",
-    "Favorite" : "Favorite",
+    "Select" : "Selectionar",
     "Delete" : "Deler",
-    "to" : "a",
-    "Reply" : "Responder",
+    "Important" : "Importante",
+    "Favorites" : "Favoritos",
+    "Other" : "Altere",
+    "Attachments" : "Attachamentos",
     "Unnamed" : "Non nominate",
     "Choose a folder to store the attachment in" : "Selectiona un dossier pro salveguardar le attachamento",
     "Settings" : "Configurationes",
+    "Quota" : "Quota",
     "Add folder" : "Add folder",
-    "Delete account" : "Delete account",
+    "Saving" : "Salveguardante",
+    "Remove account" : "Remover conto",
+    "Cancel" : "Cancellar",
     "Show all folders" : "Monstrar tote dossiers",
     "Collapse folders" : "Plicar dossiers",
+    "Delete folder" : "Deler dossier",
+    "Reply" : "Responder",
     "General" : "General",
     "User" : "User",
     "Host" : "Hospite",
     "Port" : "Porto",
+    "Keyboard shortcut" : "Combination de claves",
+    "Keyboard shortcuts" : "Combinationes de claves",
     "Search" : "Cercar",
     "Refresh" : "Refrescar",
     "All" : "Tote",
-    "Favorites" : "Favoritos",
     "All inboxes" : "Tote cassas de entrata",
     "Could not load {tag}{name}{endtag}" : "Impossibile cargar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}"
