@@ -1,9 +1,9 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Email",
     "Auto detect failed. Please use manual mode." : "Deteksi otomatis gagal. Mohon gunakan modus manual.",
     "Creating account failed: " : "Gagal membuat akun:",
+    "Mail" : "Email",
     "Name" : "Nama",
     "Password" : "Kata kunci",
     "None" : "Tidak ada",
@@ -12,7 +12,7 @@ OC.L10N.register(
     "SMTP Password" : "Kata sandi SMTP",
     "Save" : "Simpan",
     "Connect" : "Sambungkan",
-    "Keyboard shortcuts" : "Pintasan keyboard",
+    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
     "Upload attachment" : "Unggah lampiran",
     "Sending …" : "Mengirim ...",
     "Go back" : "Kembali",
@@ -20,28 +20,32 @@ OC.L10N.register(
     "Message sent!" : "Kirim pesan!",
     "Send" : "Kirim",
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
-    "Favorite" : "Favorit",
     "Unselect" : "Batal pilih",
     "Select" : "Pilih",
     "Delete" : "Hapus",
     "Important" : "Penting",
     "Favorites" : "Disukai",
     "Other" : "Lainnya",
-    "to" : "untuk",
-    "Reply" : "Balas",
+    "Attachments" : "Lampiran",
     "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
     "Settings" : "Setelan",
     "Quota" : "Kuota",
     "Add folder" : "Add folder",
+    "Saving" : "Menyimpan",
     "Remove account" : "Hapus akun",
     "Cancel" : "Membatalkan",
     "Mark all as read" : "Tandai semua telah dibaca",
+    "Edit name" : "Edit nama",
     "Clear cache" : "Bersihkan cache",
+    "Delete folder" : "Hapus folder",
     "Signature" : "Tanda",
+    "Reply" : "Balas",
     "General" : "Umum",
     "User" : "Pengguna",
     "Host" : "Host",
     "Port" : "Port",
+    "Keyboard shortcut" : "Pintasan keyboard",
+    "Keyboard shortcuts" : "Pintasan keyboard",
     "Search" : "Cari",
     "Refresh" : "Segarkan",
     "All" : "Semua",
