@@ -1,10 +1,10 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "ფოსტა",
     "Auto detect failed. Please use manual mode." : "ავტო-აღმოჩენა ვერ მოხერხდა. გთხოვთ სცადოთ ხელით.",
     "Updating account failed: " : "ანგარიშის განახლება ვერ მოხერხდა:",
     "Creating account failed: " : "ანგარიშების შექმნა ვერ მოხერხდა:",
+    "Mail" : "ფოსტა",
     "Name" : "სახელი",
     "Mail Address" : "ფოსტის მისამართი",
     "Password" : "პაროლი",
@@ -23,7 +23,6 @@ OC.L10N.register(
     "Connect" : "დაკავშირება",
     "Add mail account" : "საფოსტო ანგარიშის დამატება",
     "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
-    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Select account" : "აირჩიეთ ანგარიში",
     "Subject" : "სათაური",
     "Upload attachment" : "დანართის ატვირთვა",
@@ -34,15 +33,12 @@ OC.L10N.register(
     "Message sent!" : "წერილი გაგზავნილია!",
     "Send" : "გაგზავნა",
     "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
-    "Unfavorite" : "რჩეულებიდან ამოშლა",
-    "Favorite" : "რჩეული",
     "Mark read" : "მონიშნეთ წაკითხულად",
+    "Select" : "არჩევა",
     "Delete" : "გაუქმება",
-    "to" : "ვის",
-    "cc" : "კკ",
-    "Reply" : "პასუხი",
-    "Forward" : "წინ",
-    "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
+    "Important" : "აუცილებელი",
+    "Favorites" : "რჩეულები",
+    "Other" : "სხვა",
     "Import into calendar" : "იმპორტი კალენდარში",
     "Download attachment" : "დანართის გადმოწერა",
     "Save to Files" : "შენახვა ფაილებში",
@@ -50,18 +46,28 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
     "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
     "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
+    "Show images from this sender" : "ამ გამომგზავნელისგან სურათების ჩვენება",
     "New message" : "ახალი წერილი",
     "Settings" : "პარამეტრები",
+    "Quota" : "კვოტა",
     "Add folder" : "Add folder",
-    "Delete account" : "ანგარიშის გაუქმება",
+    "Saving" : "მიმდინარეობს შენახვა",
+    "Remove account" : "ანგარიშის გაუქმება",
+    "Cancel" : "უარყოფა",
     "Show all folders" : "ყველა დირექტორიის ჩვენება",
     "Collapse folders" : "დირექტორიების კოლაფსი",
     "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
+    "Clear cache" : "კეშის გასუფთავება",
+    "Delete folder" : "დირექტორიის გაუქმება",
     "Signature" : "ხელმოწერა",
+    "Reply" : "პასუხი",
+    "Forward" : "წინ",
     "General" : "ზოგადი",
     "User" : "მომხმარებელი",
     "Host" : "ჰოსტი",
     "Port" : "პორტი",
+    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
+    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
     "Compose new message" : "ახალი წერილის შედგენა",
     "Newer message" : "უფრო ახალი წერილი",
@@ -74,7 +80,6 @@ OC.L10N.register(
     "All" : "ყველა",
     "Archive" : "არქივი",
     "Drafts" : "მონახაზები",
-    "Favorites" : "რჩეულები",
     "All inboxes" : "ყველა ინბოქსი",
     "Inbox" : "ინბოქსი",
     "Junk" : "უსარგებლო",
@@ -85,6 +90,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud ფოსტა",
     "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ვერ ჩაიტვირთა",
     "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}-ის ჩატვირთვისას მოხდა შეცდომა",
+    "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
     "Could not load the desired message" : "სასურველი წერილის ჩატვირთვა ვერ მოხერხდა",
     "Could not load the message" : "წერილის ჩატვირთვა ვერ მოხერხდა",
     "Error loading message" : "წერილის ჩატვირთვისას წარმოიშვა შეცდომა",
