@@ -1,8 +1,8 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "សំបុត្រ",
     "Creating account failed: " : "ការបង្កើត​គណនី​បរាជ័យ",
+    "Mail" : "សំបុត្រ",
     "Name" : "ឈ្មោះ",
     "Password" : "ពាក្យសម្ងាត់",
     "None" : "គ្មាន",
@@ -15,11 +15,11 @@ OC.L10N.register(
     "Important" : "សំខាន់",
     "Favorites" : "Favorites",
     "Other" : "ផ្សេងៗ",
-    "to" : "ទៅ",
-    "Reply" : "ឆ្លើយតប",
     "Settings" : "ការកំណត់",
     "Add folder" : "Add folder",
     "Cancel" : "បោះបង់",
+    "Delete folder" : "លុប​ថត",
+    "Reply" : "ឆ្លើយតប",
     "General" : "ទូទៅ",
     "User" : "User",
     "Host" : "ម៉ាស៊ីន​ផ្ទុក",
