@@ -1,10 +1,12 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "메일",
     "Auto detect failed. Please use manual mode." : "자동 감지가 실패했습니다. 수동 모드를 사용하십시오.",
     "Updating account failed: " : "계정 업데이트 실패:",
     "Creating account failed: " : "계정 생성 실패: ",
+    "Important mail" : "중요 메일",
+    "Mails" : "메일",
+    "Mail" : "메일",
     "💌 A mail app for Nextcloud" : "Nextcloud 메일 앱",
     "Auto" : "자동",
     "Name" : "이름",
@@ -28,9 +30,10 @@ OC.L10N.register(
     "SMTP Password" : "SMTP 암호",
     "Save" : "저장",
     "Connect" : "연결",
+    "Add alias" : "별칭 추가",
     "Add mail account" : "메일 계정 추가",
     "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
-    "Keyboard shortcuts" : "키보드 단축키",
+    "Show keyboard shortcuts" : "키보드 단축키 표시",
     "From" : "보낸사람",
     "Select account" : "계정 선택",
     "To" : "받는사람",
@@ -61,11 +64,15 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
     "Choose a file to share as a link" : "공유할 링크 파일을 선택하십시오",
     "Writing mode" : "쓰기 모드",
+    "Plain text" : "평문",
+    "Rich text" : "서식 있는 텍스트",
+    "No messages in this folder" : "이 폴더에 메시지가 없음",
+    "No messages" : "메시지가 없음",
     "Draft: " : "임시 보관함",
-    "Unfavorite" : "즐겨찾기에서 삭제",
-    "Favorite" : "즐겨찾기",
     "Mark unimportant" : "중요하지 않음 표시",
     "Mark important" : "중요함 표시",
+    "Mark unfavorite" : "즐겨찾기 표시 제거",
+    "Mark favorite" : "즐겨찾기 표시",
     "Mark unread" : "읽지 않음 상태로 표시",
     "Mark read" : "읽은 상태로 표시",
     "Mark not spam" : "스팸 해제",
@@ -78,16 +85,15 @@ OC.L10N.register(
     "Favorite " : "즐겨찾기",
     "Unselect " : "선택 해제",
     "Delete " : "삭제",
+    "Load more" : "더 불러오기",
+    "Report this bug" : "이 오류 보고",
+    "Could not open mailbox" : "메일함을 열 수 없음",
     "Loading messages" : "메세지를 불러오는 중",
     "Important" : "중요",
+    "Important info" : "중요 정보",
     "Favorites" : "즐겨찾기",
     "Other" : "기타",
-    "Not found" : "찾을 수 없음",
-    "to" : "받는 사람",
-    "cc" : "참조",
-    "Reply" : "답장",
-    "Forward" : "전달",
-    "Could not load your message" : "메시지를 불러올 수 없음",
+    "Attachments" : "첨부파일",
     "Import into calendar" : "달력으로 가져오기",
     "Download attachment" : "첨부 파일 다운로드",
     "Save to Files" : "파일에 저장",
@@ -99,20 +105,46 @@ OC.L10N.register(
     "New message" : "새로운 메시지",
     "Settings" : "설정",
     "Quota" : "할당량",
-    "Edit account" : "계정 편집",
     "Add folder" : "폴더 추가",
+    "Saving" : "저장 중",
+    "Move up" : "위로 이동",
+    "Move down" : "아래로 이동",
     "Remove account" : "계정 삭제",
     "Loading …" : "불러오는 중 …",
+    "Remove account {email}" : "{email} 계정 제거",
+    "Remove {email}" : "{email} 제거",
     "Cancel" : "취소",
+    "Show all subscribed folders" : "구독 폴더 모두 표시",
     "Show all folders" : "모든 폴더 보기",
     "Collapse folders" : "폴더 접기",
     "Mark all as read" : "모두 읽은 것으로 표시",
+    "Add subfolder" : "하위 폴더 추가",
+    "Edit name" : "이름 편집",
     "Clear cache" : "Clear cache",
+    "Subscribed" : "구독함",
+    "Delete folder" : "폴더 삭제",
+    "Delete folder {name}" : "{name} 폴더 삭제",
+    "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
+    "Not found" : "찾을 수 없음",
     "Signature" : "서명",
+    "Signature …" : "서명 …",
+    "Save signature" : "서명 저장",
+    "Reply" : "답장",
+    "Forward" : "전달",
+    "Airplane" : "여객기",
+    "Reservation {id}" : "예약 {id}",
+    "Train" : "열차",
     "General" : "일반",
+    "IMAP" : "IMAP",
     "User" : "사용자",
     "Host" : "호스트",
     "Port" : "포트",
+    "SMTP" : "SMTP",
+    "Change name" : "이름 변경",
+    "Mail server" : "메일 서버",
+    "Set up an account" : "계정 설정",
+    "Keyboard shortcut" : "키보드 단축키",
+    "Keyboard shortcuts" : "키보드 단축키",
     "Speed up your Mail experience with these quick shortcuts." : "빠른 단축키로 메일 사용을 더 빠르게 할 수 있습니다.",
     "Compose new message" : "새 메시지 작성",
     "Newer message" : "새로운 메시지",
@@ -125,6 +157,7 @@ OC.L10N.register(
     "All" : "모두",
     "Archive" : "보관",
     "Drafts" : "임시 보관함",
+    "Priority inbox" : "우선 받은편지함",
     "All inboxes" : "모든 받은 편지함",
     "Inbox" : "받은 편지함",
     "Junk" : "스팸 메일함",
@@ -135,6 +168,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud 메일",
     "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러올 수 없음",
     "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러오는 중 문제 발생",
+    "Could not load your message" : "메시지를 불러올 수 없음",
     "Could not load the desired message" : "원하는 메시지를 불러올 수 없음",
     "Could not load the message" : "메시지를 불러올 수 없음",
     "Error loading message" : "메시지 불러오기 오류",
