@@ -10,20 +10,20 @@ OC.L10N.register(
     "Select account" : "Account auswielen",
     "Go back" : "Zeréckgoen",
     "Send" : "Schécken",
-    "Favorite" : "Favorit",
     "Select" : "Select",
     "Delete" : "Läschen",
     "Important" : "Wichteg",
     "Favorites" : "Favoriten",
     "Other" : "Aner",
-    "to" : "bis",
-    "Reply" : "Äntwerten",
     "Unnamed" : "ouni Numm",
     "Settings" : "Astellungen",
     "Quota" : "Quota",
     "Add folder" : "Add folder",
+    "Saving" : "Speicheren...",
     "Remove account" : "De Kont läschen",
     "Cancel" : "Ofbriechen",
+    "Delete folder" : "Dossier läschen",
+    "Reply" : "Äntwerten",
     "General" : "Allgemeng",
     "User" : "User",
     "Host" : "Host",
