@@ -1,11 +1,12 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Paštas",
     "Auto detect failed. Please use manual mode." : "Automatinis nustatymų aptikimas nepavyko. Įveskite duomenis rankiniu būdu.",
     "Updating account failed: " : "Paskyros atnaujinimas nepavyko: ",
     "Creating account failed: " : "Paskyros sukūrimas nepavyko: ",
     "Embedded message %s" : "Įterptas laiškas %s",
+    "Mails" : "El. laiškai",
+    "Mail" : "Paštas",
     "💌 A mail app for Nextcloud" : "💌 Pašto programėlė, skirta Nextcloud",
     "Auto" : "Automatiškai",
     "Name" : "Vardas",
@@ -31,7 +32,7 @@ OC.L10N.register(
     "Connect" : "Prisijungti",
     "Add mail account" : "Pridėti pašto paskyrą",
     "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
-    "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
+    "Show keyboard shortcuts" : "Rodyti klaviatūros kombinacijas",
     "From" : "Nuo",
     "Select account" : "Pasirinkti paskyrą",
     "To" : "Kam",
@@ -67,8 +68,6 @@ OC.L10N.register(
     "Rich text" : "Raiškusis tekstas",
     "No messages in this folder" : "Šiame aplankė pranešimų nėra",
     "Draft: " : "Juodraštis: ",
-    "Unfavorite" : "Nebežymėti kaip mėgstamą",
-    "Favorite" : "Mėgstamas",
     "Mark unimportant" : "Žymėti kaip nesvarbų",
     "Mark important" : "Žymėti kaip svarbų",
     "Mark unread" : "Žymėti kaip neskaitytą",
@@ -84,13 +83,7 @@ OC.L10N.register(
     "Important" : "Svarbios",
     "Favorites" : "Mėgstamos",
     "Other" : "Kita",
-    "Not found" : "Nerasta",
-    "to" : "iki",
-    "cc" : "cc",
-    "Reply" : "Atsakyti",
-    "Reply to sender only" : "Atsakyti tik siuntėjui",
-    "Forward" : "Persiųsti",
-    "Could not load your message" : "Nepavyko įkelti jūsų laiško",
+    "Attachments" : "Priedai",
     "Import into calendar" : "Importuoti į kalendorių",
     "Download attachment" : "Atsisiųsti priedą",
     "Save to Files" : "Įrašyti į Failus",
@@ -105,28 +98,38 @@ OC.L10N.register(
     "New message" : "Naujas laiškas",
     "Settings" : "Nustatymai",
     "Quota" : "Leidžiamas duomenų kiekis",
-    "Edit account" : "Taisyti paskyrą",
+    "Account settings" : "Paskyros nustatymai",
     "Add folder" : "Pridėti aplanką",
-    "Move Up" : "Pakelti",
+    "Saving" : "Įrašoma",
+    "Move up" : "Pakelti",
     "Move down" : "Nuleisti",
     "Remove account" : "Šalinti paskyrą",
     "Loading …" : "Įkeliama…",
+    "Not supported by the server" : "Serveris nepalaiko",
+    "{usage} of {limit} used" : "Panaudota {usage} iš {limit}",
     "Remove account {email}" : "Šalinti paskyrą {email}",
     "Remove {email}" : "Šalinti {email}",
     "Cancel" : "Atsisakyti",
     "Show all folders" : "Rodyti visus aplankus",
     "Collapse folders" : "Suskleisti aplankus",
     "Mark all as read" : "Žymėti visus kaip skaitytus",
-    "Mark all messages of this folder as read" : "Žymėti visus laiškus šiame aplanke kaip skaitytus",
     "Add subfolder" : "Pridėti poaplankį",
+    "Edit name" : "Taisyti pavadinimą",
     "Clear cache" : "Išvalyti podėlį",
+    "Delete folder" : "Ištrinti aplanką",
+    "Delete folder {name}" : "Ištrinti aplanką {name}",
+    "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
     "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
+    "Not found" : "Nerasta",
     "Could not load your draft" : "Nepavyko įkelti jūsų juodraščio",
     "Could not load original message" : "Nepavyko įkelti pradinio laiško",
     "Signature" : "Parašas",
     "A signature is added to the text of new messages and replies." : "Parašas yra pridedamas į naujų ir atsakomųjų laiškų tekstą.",
     "Signature …" : "Parašas…",
     "Save signature" : "Įrašyti parašą",
+    "Reply" : "Atsakyti",
+    "Reply to sender only" : "Atsakyti tik siuntėjui",
+    "Forward" : "Persiųsti",
     "Import into {calendar}" : "Importuoti į {calendar}",
     "Event imported into {calendar}" : "Įvykis importuotas į {calendar}",
     "Could not create event" : "Nepavyko sukurti įvykio",
@@ -141,6 +144,7 @@ OC.L10N.register(
     "Email: {email}" : "El. paštas: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} ties {host}:{port} ({ssl} šifravimas)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} ties {host}:{port} ({ssl} šifravimas)",
+    "Provision an account for every user" : "Parūpinti paskyrą kiekvienam naudotojui",
     "General" : "Bendra",
     "Email address" : "El. pašto adresas",
     "IMAP" : "IMAP",
@@ -149,9 +153,10 @@ OC.L10N.register(
     "Port" : "Prievadas",
     "SMTP" : "SMTP",
     "Apply and create/update for all users" : "Taikyti ir sukurti/atnaujinti visiems naudotojams",
-    "Account settings" : "Paskyros nustatymai",
     "Change name" : "Keisti vardą",
     "Mail server" : "Pašto serveris",
+    "Keyboard shortcut" : "Spartusis klavišas",
+    "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
     "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
     "Compose new message" : "Rašyti naują laišką",
     "Newer message" : "Naujesni laiškai",
@@ -176,6 +181,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud el. paštas",
     "Could not load {tag}{name}{endtag}" : "Nepavyko įkelti {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Įvyko klaida bandant parodyti {tag}{name}{endtag}",
+    "Could not load your message" : "Nepavyko įkelti jūsų laiško",
     "Could not load the desired message" : "Nepavyko įkelti pageidaujamo laiško",
     "Could not load the message" : "Nepavyko įkelti laiško",
     "Error loading message" : "Klaida, įkeliant laišką",
