@@ -1,8 +1,8 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "шуудан",
     "Creating account failed: " : "аккаунт үүсгэж чадсангүй:",
+    "Mail" : "шуудан",
     "Name" : "нэр",
     "Mail Address" : "шуудангийн хаяг",
     "Password" : "нууц үг",
@@ -25,33 +25,40 @@ OC.L10N.register(
     "Retry" : "Дахин оролдох",
     "Message sent!" : "зурвас илгээсэн",
     "Send" : "илгээх",
-    "Favorite" : "Дуртай",
+    "Select" : "Сонгох",
     "Delete" : "Устгах",
-    "to" : "Дуусах нь",
-    "Reply" : "хариулт",
-    "Forward" : "дамжих",
+    "Favorites" : "Онцолсон",
+    "Other" : "Бусад",
+    "Attachments" : "Хавсралт",
     "Download attachment" : "Татаж авах хавсралт",
     "Save to Files" : "Файлд хадгална",
     "Choose a folder to store the attachment in" : "-д хавсралт хадгалах фолдер сонгоно уу",
     "Save all to Files" : "бүх файлыг хадгалах",
     "The images have been blocked to protect your privacy." : " таны хувийн нууцыг хамгаалахын тулд дүрсийг хаасан байна.",
+    "Show images from this sender" : " илгээгчээс харуулах зургууд",
     "New message" : "шинэ зурвас",
     "Settings" : "тохиргоо",
+    "Quota" : " хувь хэмжээ",
     "Add folder" : "Add folder",
-    "Delete account" : "аккаунтыг устгах",
+    "Saving" : "хадгаламж",
+    "Remove account" : "Аккаунт устгах",
+    "Cancel" : "болиулах",
     "Show all folders" : "Бүх хавтас харуулах",
+    "Delete folder" : "Хавтсыг устгах",
     "Signature" : "Гарын үсэг",
+    "Reply" : "хариулт",
+    "Forward" : "дамжих",
     "General" : "Ерөнхий",
     "User" : "Хэрэглэгч",
     "Host" : "хост",
     "Port" : "порт",
+    "Keyboard shortcut" : "Keyboard товчлуур",
     "Search" : "Хайх",
     "Refresh" : "Сэргээх",
     "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
     "All" : "бүх",
     "Archive" : "архив",
     "Drafts" : "ноорог",
-    "Favorites" : "Онцолсон",
     "Inbox" : "ирсэн",
     "Junk" : "хэрэггүй",
     "Sent" : "илгээсэн",
