@@ -1,10 +1,10 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "E-post",
     "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
     "Updating account failed: " : "Oppdatering av konto mislyktes:",
     "Creating account failed: " : "Oppretting av konto mislyktes:",
+    "Mail" : "E-post",
     "Auto" : "Auto",
     "Name" : "Navn",
     "Mail Address" : "E-postadresse",
@@ -29,7 +29,7 @@ OC.L10N.register(
     "Connect" : "Koble til",
     "Add mail account" : "Legg til e-postkonto",
     "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
-    "Keyboard shortcuts" : "Tastatursnarveier",
+    "Show keyboard shortcuts" : "Vis tastatursnarveier",
     "Select account" : "Velg konto",
     "Subject" : "Emne",
     "Saving draft …" : "Lagrer kladd…",
@@ -47,19 +47,17 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
     "No messages in this folder" : "Ingen meldinger i denne mappen",
     "Draft: " : "Kladd:",
-    "Unfavorite" : "Fjern favorittmarkering",
-    "Favorite" : "Merk som favoritt",
-    "Mark read" : "Marker som lest",
     "Mark unread" : "Marker som ulest",
+    "Mark read" : "Marker som lest",
+    "Unselect" : "Velg bort",
+    "Select" : "Velg",
     "Delete" : "Slett",
     "Report this bug" : "Rapporter denne feilen",
     "Loading messages" : "Henter meldinger",
-    "Not found" : "Ikke funnet",
-    "to" : "til",
-    "cc" : "cc",
-    "Reply" : "Svar",
-    "Forward" : "Fremover",
-    "Could not load your message" : "Kunne ikke laste meldingene dine",
+    "Important" : "Viktig",
+    "Favorites" : "Favoritter",
+    "Other" : "Annet",
+    "Attachments" : "Vedlegg",
     "Import into calendar" : "Importer til kalender",
     "Download attachment" : "Last ned vedlegg",
     "Save to Files" : "Lagre i Filer",
@@ -68,21 +66,34 @@ OC.L10N.register(
     "Save all to Files" : "Lagre alle i Filer",
     "Choose a folder to store the attachments in" : "Velg en mappe å lagre vedleggene i",
     "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
-    "Show images from this\tsender" : "Vis bilder fra denne avsenderen",
+    "Show images from this sender" : "Vis bilder fra denne avsenderen",
     "New message" : "Ny melding",
     "Settings" : "Innstillinger",
+    "Quota" : "Kvote",
     "Add folder" : "Legg til mappe",
-    "Delete account" : "Slett konto",
+    "Saving" : "Lagrer",
+    "Remove account" : "Fjern konto",
+    "Loading …" : "Laster...",
+    "Cancel" : "Avbryt",
     "Show all folders" : "Vis alle mapper",
     "Collapse folders" : "Skjul mapper",
     "Mark all as read" : "Marker alle som lest",
-    "Loading …" : "Laster...",
+    "Edit name" : "Rediger navn",
+    "Clear cache" : "Tøm hurtiglager",
+    "Delete folder" : "Slett mappe",
+    "Not found" : "Ikke funnet",
     "Could not load your draft" : "Kunne ikke laste inn denne kladden",
     "Signature" : "Signatur",
+    "Reply" : "Svar",
+    "Forward" : "Fremover",
     "General" : "Generell",
+    "Email address" : "E-post adresse",
     "User" : "Bruker",
     "Host" : "Server",
     "Port" : "Port",
+    "Change name" : "Bytt navn",
+    "Keyboard shortcut" : "Hurtigtast",
+    "Keyboard shortcuts" : "Tastatursnarveier",
     "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
     "Compose new message" : "Lag ny melding",
     "Newer message" : "Nyere melding",
@@ -95,7 +106,6 @@ OC.L10N.register(
     "All" : "Alle",
     "Archive" : "Arkiv",
     "Drafts" : "Kladder",
-    "Favorites" : "Favoritter",
     "All inboxes" : "Alle innbokser",
     "Inbox" : "Innboks",
     "Junk" : "Søppel",
@@ -106,6 +116,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud Mail",
     "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
+    "Could not load your message" : "Kunne ikke laste meldingene dine",
     "Could not load the desired message" : "Kunne ikke laste den ønskede meldingen",
     "Could not load the message" : "Kunne ikke laste meldingen",
     "Error loading message" : "Feil ved innlasting av melding",
