@@ -7,24 +7,23 @@ OC.L10N.register(
     "None" : "Ingen",
     "Save" : "Lagre",
     "Connect" : "Kopla til",
-    "Keyboard shortcuts" : "Tastatursnarvegar",
     "Retry" : "Forsøk att",
     "Send" : "Send",
-    "Favorite" : "Favoritt",
     "Select" : "Vel",
     "Delete" : "Ta bort",
     "Important" : "Viktig",
     "Favorites" : "Favorit",
     "Other" : "Anna",
-    "to" : "til",
     "Settings" : "Instillingar",
     "Quota" : "Kvote",
     "Add folder" : "Add folder",
     "Cancel" : "Avbryt",
+    "Delete folder" : "Slett mappe",
     "Signature" : "Signatur",
     "General" : "Generelt",
     "User" : "Bruker",
     "Host" : "Tenar",
+    "Keyboard shortcuts" : "Tastatursnarvegar",
     "Search" : "Search",
     "Refresh" : "Last inn på nytt",
     "All" : "Alle",
