@@ -1,9 +1,9 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Correio",
     "Auto detect failed. Please use manual mode." : "A deteção automática falhou. Por favor, utilize o modo manual",
     "Creating account failed: " : "Não foi possível criar a conta:",
+    "Mail" : "Correio",
     "Name" : "Nome",
     "Mail Address" : "Endereço de Correio",
     "Password" : "Palavra-passe",
@@ -15,7 +15,6 @@ OC.L10N.register(
     "SMTP Password" : "Palavra-passe SMTP",
     "Save" : "Guardar",
     "Connect" : "Ligar",
-    "Keyboard shortcuts" : "Atalhos de teclado",
     "Subject" : "Assunto",
     "Saving draft …" : "A guardar rascunho ...",
     "Draft saved" : "Rascunho guardado",
@@ -28,38 +27,46 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
     "Plain text" : "Texto simples",
     "Draft: " : "Rascunho:",
-    "Unfavorite" : "Não favorito",
-    "Favorite" : "Favorito",
-    "Mark read" : "Marcar como lido",
     "Mark unread" : "Marcar como não lido",
+    "Mark read" : "Marcar como lido",
+    "Select" : "Seleccionar",
     "Delete" : "Eliminar",
-    "to" : "Para",
-    "Reply" : "Resposta",
-    "Reply to sender only" : "Resposta apenas ao remetente",
-    "Forward" : "Encaminhar",
+    "Important" : "Importante",
+    "Favorites" : "Favoritos",
+    "Other" : "Outro",
+    "Attachments" : "Anexos",
     "Download attachment" : "Transferir anexo",
     "Save to Files" : "Guardar em Ficheiros",
     "Unnamed" : "Sem nome",
     "Choose a folder to store the attachment in" : "Escolha uma pasta para guardar o anexo",
     "Save all to Files" : "Guardar todos em Ficheiros",
     "Settings" : "Definições",
-    "Edit account" : "Editar conta",
+    "Quota" : "Quota",
     "Add folder" : "Add folder",
-    "Delete account" : "Apagar conta",
+    "Saving" : "A guardar",
+    "Remove account" : "Remover conta",
+    "Cancel" : "Cancelar",
     "Show all folders" : "Mostrar todas as pastas",
     "Collapse folders" : "Ocultar pastas",
     "Mark all as read" : "Marcar todas como lidas",
+    "Edit name" : "Editar nome",
+    "Clear cache" : "Limpar cache",
+    "Delete folder" : "Eliminar pasta",
     "Signature" : "Assinatura",
+    "Reply" : "Resposta",
+    "Reply to sender only" : "Resposta apenas ao remetente",
+    "Forward" : "Encaminhar",
     "General" : "Geral",
     "User" : "Utilizador",
     "Host" : "Anfitrião",
     "Port" : "Porta",
+    "Keyboard shortcut" : "Atalho de teclado",
+    "Keyboard shortcuts" : "Atalhos de teclado",
     "Search" : "Pesquisar",
     "Refresh" : "Atualizar",
     "All" : "Todos",
     "Archive" : "Arquivar",
     "Drafts" : "Rascunhos",
-    "Favorites" : "Favoritos",
     "All inboxes" : "Todas as caixas de entrada",
     "Inbox" : "Caixa de Entrada",
     "Junk" : "Lixo",
