@@ -1,8 +1,8 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Mail",
     "Creating account failed: " : "Crearea contului a eșuat:",
+    "Mail" : "Mail",
     "Name" : "Nume",
     "Mail Address" : "Adresă Mail",
     "Password" : "Parolă",
@@ -14,7 +14,6 @@ OC.L10N.register(
     "SMTP Password" : "Parolă SMTP",
     "Save" : "Salvează",
     "Connect" : "Conectare",
-    "Keyboard shortcuts" : "Scurtături din tastatură",
     "Select account" : "Selectează cont",
     "Subject" : "Subiect",
     "Sending …" : "Se trimite...",
@@ -22,30 +21,32 @@ OC.L10N.register(
     "Retry" : "Reîncearcă",
     "Message sent!" : "Mesaj trimis!",
     "Send" : "Trimite",
-    "Favorite" : "Favorite",
     "Select" : "Select",
     "Delete" : "Șterge",
     "Important" : "Important",
     "Favorites" : "Favorite",
     "Other" : "Altele",
-    "to" : "către",
-    "Reply" : "Răspunde",
     "Unnamed" : "Fără nume",
     "Choose a folder to store the attachment in" : "Alege un dosar în care să stochez atașamentul",
     "Settings" : "Setări",
     "Quota" : "Procent",
     "Add folder" : "Add folder",
+    "Saving" : "Se salvează",
     "Remove account" : "Sterge contul",
     "Loading …" : "Se încarcă…",
     "Cancel" : "Anulează",
     "Show all folders" : "Arată toate directoarele",
     "Mark all as read" : "Marcaţi tot ca fiind citit",
+    "Edit name" : "Modifică numele",
     "Clear cache" : "Șterge cache",
+    "Delete folder" : "Șterge director",
     "Signature" : "Semnătură",
+    "Reply" : "Răspunde",
     "General" : "General",
     "User" : "Utilizator",
     "Host" : "Gazdă",
     "Port" : "Portul",
+    "Keyboard shortcuts" : "Scurtături din tastatură",
     "Search" : "Caută",
     "Refresh" : "Reîmprospătează",
     "All" : "Toate ",
