@@ -1,9 +1,9 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Posta",
     "Auto detect failed. Please use manual mode." : "Vetëzbulimi dështoi. Ju lutemi, përdorni metodën dorazi.",
     "Creating account failed: " : "Krijimi i llogarisë dështoi: ",
+    "Mail" : "Posta",
     "Name" : "Emri",
     "Mail Address" : "Adresa e postës elektronike",
     "Password" : "Fjalëkalimi",
@@ -21,7 +21,6 @@ OC.L10N.register(
     "Save" : "Ruaj",
     "Connect" : "Lidhu",
     "Add mail account" : "Shto llogarinë e postës elektronike",
-    "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Select account" : "Përzgjidhni llogari",
     "Subject" : "Temë",
     "Upload attachment" : "Ngarko bashkëngjitje",
@@ -32,18 +31,13 @@ OC.L10N.register(
     "Message sent!" : "Mesazhi u dërgua!",
     "Send" : "Dërgo",
     "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
-    "Unfavorite" : "Jo i/e preferuar",
-    "Favorite" : "I/E Preferuar",
     "Mark read" : "Shëno të lexuar",
     "Select" : "Zgjidhni",
     "Delete" : "Fshij",
     "Important" : "E rëndësishme",
     "Favorites" : "Favorites",
     "Other" : "Tjetër",
-    "to" : "te",
-    "cc" : "cc",
-    "Reply" : "Përgjigju",
-    "Forward" : "Përpara",
+    "Attachments" : "Bashkangjitjet",
     "Import into calendar" : "Importo në kalendar",
     "Download attachment" : "Shkarko bashkëlidhjen",
     "Save to Files" : "Ruaje te Skedarët",
@@ -56,17 +50,23 @@ OC.L10N.register(
     "Settings" : "Konfigurimet",
     "Quota" : "Kuotë",
     "Add folder" : "Shto dosje",
+    "Saving" : "Duke u ruajtur!",
     "Remove account" : "Fshij llogarinë",
     "Cancel" : "Anullo",
     "Show all folders" : "Shfaqi krejt dosjet",
     "Collapse folders" : "Tkurri dosjet",
     "Mark all as read" : "Shënoji krejt si të lexuar",
     "Clear cache" : "Pastroje fshehtinën",
+    "Delete folder" : "Fshini dosjen",
     "Signature" : "Nënshkrimi",
+    "Reply" : "Përgjigju",
+    "Forward" : "Përpara",
     "General" : "Të përgjithshme",
     "User" : "Përdorues",
     "Host" : "Strehë",
     "Port" : "Porta",
+    "Keyboard shortcut" : "Shkurtore tastiere",
+    "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Speed up your Mail experience with these quick shortcuts." : "Përmirësoni përvojën tuaj në Mail me këto shkurtore të shpejta.",
     "Newer message" : "Mesazhe më të reja",
     "Older message" : "Mesazhe më të vjetra",
