@@ -9,19 +9,19 @@ OC.L10N.register(
     "Connect" : "Poveži se",
     "Select account" : "Označite nalog",
     "Send" : "Pošalji",
-    "Favorite" : "Omiljene",
     "Select" : "Obeleži",
     "Delete" : "Delete",
     "Favorites" : "Omiljene",
     "Other" : "Ostali",
-    "Reply" : "Odgovori",
-    "Forward" : "Prosledi",
+    "Attachments" : "Prilozi",
     "Settings" : "Postavke",
     "Add folder" : "Add folder",
     "Remove account" : "Ukloni nalog",
     "Cancel" : "Otkaži",
     "Mark all as read" : "Označi sve kao pročitano",
     "Clear cache" : "Očisti keš",
+    "Reply" : "Odgovori",
+    "Forward" : "Prosledi",
     "General" : "Opšte",
     "User" : "User",
     "Search" : "Search",
