@@ -6,8 +6,6 @@ OC.L10N.register(
     "None" : "ஒன்றுமில்லை",
     "Save" : "சேமிக்க ",
     "Connect" : "இணைக்க",
-    "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
-    "Favorite" : "விருப்பமான",
     "Select" : "Select",
     "Delete" : "நீக்குக",
     "Important" : "முக்கியமான ",
@@ -17,10 +15,12 @@ OC.L10N.register(
     "Quota" : "பங்கு",
     "Add folder" : "Add folder",
     "Cancel" : "இரத்து செய்க",
+    "Delete folder" : "கோப்பை அழிக்க",
     "General" : "பொதுவான",
     "User" : "User",
     "Host" : "ஓம்புனர்",
     "Port" : "துறை ",
+    "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
     "Search" : "Search",
     "Refresh" : "மீள் ஏற்றுக",
     "All" : "எல்லாம்"
