@@ -1,44 +1,45 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "จดหมาย",
     "Auto detect failed. Please use manual mode." : "ตรวจจับอัตโนมัติล้มเหลว กรุณาใช้โหมดควบคุมด้วยตนเอง",
     "Creating account failed: " : "สร้างบัญชีล้มเหลว:",
+    "Mail" : "จดหมาย",
     "Name" : "ชื่อ",
     "Password" : "รหัสผ่าน",
     "None" : "ไม่มี",
     "SMTP Password" : "รหัสผ่าน SMTP",
     "Save" : "บันทึก",
     "Connect" : "เชื่อมต่อ",
-    "Keyboard shortcuts" : "ปุ่มลัด",
     "Sending …" : "กำลังส่ง ...",
     "Go back" : "กลับไป",
     "Message sent!" : "ส่งข้อความ!",
     "Send" : "ส่ง",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
-    "Favorite" : "รายการโปรด",
     "Select" : "Select",
     "Delete" : "ลบ",
     "Important" : "สำคัญ",
     "Favorites" : "รายการโปรด",
     "Other" : "อื่นๆ",
-    "to" : "ถึง",
-    "Reply" : "ตอบกลับ",
     "Unnamed" : "ไม่มีชื่อ",
     "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บสิ่งที่แนบมาใน",
     "Settings" : "ตั้งค่า",
     "Quota" : "โควต้า",
     "Add folder" : "Add folder",
+    "Saving" : "บันทึก",
     "Remove account" : "ลบบัญชี",
     "Cancel" : "ยกเลิก",
     "Show all folders" : "แสดงโฟลเดอร์ทั้งหมด",
     "Collapse folders" : "ยุบโฟลเดอร์",
     "Mark all as read" : "เลือกอ่านทั้งหมด",
     "Clear cache" : "ล้างแคช",
+    "Delete folder" : "ลบโฟลเดอร์",
+    "Reply" : "ตอบกลับ",
     "General" : "ทั่วไป",
     "User" : "User",
     "Host" : "โฮสต์",
     "Port" : "พอร์ต",
+    "Keyboard shortcut" : "แป้นพิมพ์ลัด",
+    "Keyboard shortcuts" : "ปุ่มลัด",
     "Search" : "Search",
     "Refresh" : "รีเฟรช",
     "All" : "ทั้งหมด",
