@@ -7,16 +7,16 @@ OC.L10N.register(
     "Save" : "ساقلا",
     "Connect" : "باغلان",
     "Send" : "يوللا",
-    "Favorite" : "يىغقۇچ",
     "Select" : "Select",
     "Delete" : "ئۆچۈر",
     "Important" : "مۇھىم",
     "Favorites" : "يىغقۇچ",
     "Other" : "باشقا",
-    "Reply" : "جاۋاب قايتۇر",
     "Settings" : "تەڭشەكلەر",
     "Add folder" : "Add folder",
     "Cancel" : "ۋاز كەچ",
+    "Delete folder" : "قىسقۇچ ئۆچۈر",
+    "Reply" : "جاۋاب قايتۇر",
     "General" : "ئادەتتىكى",
     "User" : "User",
     "Host" : "باش ئاپپارات",
