@@ -1,11 +1,12 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Пошта",
     "Auto detect failed. Please use manual mode." : "Автоматичне виявлення не спрацювало. Будь ласка, скористайтесь ручним режимом.",
     "Updating account failed: " : "Оновлення облікового запису не вдалося:",
     "Creating account failed: " : "Помилка створення облікового запису:",
     "Embedded message %s" : "Вбудоване повідомлення %s",
+    "Mails" : "Пошта",
+    "Mail" : "Пошта",
     "💌 A mail app for Nextcloud" : "💌 Поштовий застосунок для Nextcloud",
     "Auto" : "Автоматично",
     "Name" : "Ім'я",
@@ -32,7 +33,7 @@ OC.L10N.register(
     "Add mail account" : "Додати обліковий запис",
     "Use Gravatar and favicon avatars" : "Використовувати Gravatar та улюблені піктограми",
     "Register as application for mail links" : "Зробити типовим застосунком ел.пошти",
-    "Keyboard shortcuts" : "Гарячі клавіші",
+    "Show keyboard shortcuts" : "Показати гарячі клавіші",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволити застосунку збирати дані про вашу взаємодію. На основі цих даних застосунок буде підлаштовувати видачу. Дані зберігатимуться виключно локально.",
     "From" : "Від",
     "Select account" : "Оберіть обліковий запис",
@@ -72,8 +73,6 @@ OC.L10N.register(
     "No messages in this folder" : "Відсутні повідомлення у цій теці",
     "No messages" : "Відсутні повідомлення",
     "Draft: " : "Чернетка:",
-    "Unfavorite" : "Не улюблене",
-    "Favorite" : "До улюблених",
     "Mark unimportant" : "Позначити як неважливе",
     "Mark important" : "Позначити як важливе",
     "Mark unread" : "Позначити як не прочитане",
@@ -97,15 +96,7 @@ OC.L10N.register(
     "Important" : "Важливі",
     "Favorites" : "Улюблене",
     "Other" : "Інші",
-    "Not found" : "Не знайдено",
-    "to" : "до",
-    "cc" : "копія",
-    "Reply" : "Відповісти",
-    "Reply to sender only" : "Відповісти лише відправникові",
-    "Forward" : "Переслати",
-    "View source" : "Джерело",
-    "Message source" : "Джерело повідомлення",
-    "Could not load your message" : "Неможливо завантажити повідомлення",
+    "Attachments" : "Вкладення",
     "Import into calendar" : "Імпортувати до календаря",
     "Download attachment" : "Звантажити вкладення",
     "Save to Files" : "Зберегти до Файлів",
@@ -119,10 +110,10 @@ OC.L10N.register(
     "New message" : "Нове повідомлення",
     "Settings" : "Налаштування",
     "Quota" : "Обмеження",
-    "Edit account" : "Редагувати обліковий запис",
+    "Account settings" : "Налаштування облікового запису",
     "Show only subscribed folders" : "Показувати лише підписані теки",
     "Add folder" : "Додати теку",
-    "Move Up" : "Пересунути вгору",
+    "Saving" : "Збереження",
     "Move down" : "Пересунути вниз",
     "Remove account" : "Вилучити обліковий запис",
     "Loading …" : "Завантаження...",
@@ -135,10 +126,12 @@ OC.L10N.register(
     "Show all folders" : "Переглянути всі теки",
     "Collapse folders" : "Згорнути теки",
     "Mark all as read" : "Всі прочитані",
-    "Mark all messages of this folder as read" : "Позначити усі повідомлення у цій теці як прочитані",
     "Add subfolder" : "Додати підтеку",
+    "Edit name" : "Редагувати назву",
     "Clear cache" : "Очистити кеш",
+    "Delete folder" : "Вилучити теку",
     "_{total} message_::_{total} messages_" : ["{total] повідомлення","{total] повідомлення","{total] повідомлень","{total} повідомлень"],
+    "Not found" : "Не знайдено",
     "Could not load your draft" : "Неможливо завантажити чернетку",
     "Could not load original message" : "Неможливо завантажити оригінал повідомлення",
     "No message selected" : "Жодне повідомлення не вибрано",
@@ -146,6 +139,11 @@ OC.L10N.register(
     "A signature is added to the text of new messages and replies." : "Додавати підпис до тексту нових повідомлень та відповідей.",
     "Signature …" : "Підпис...",
     "Save signature" : "Зберегти підпис",
+    "Reply" : "Відповісти",
+    "Reply to sender only" : "Відповісти лише відправникові",
+    "Forward" : "Переслати",
+    "View source" : "Джерело",
+    "Message source" : "Джерело повідомлення",
     "Import into {calendar}" : "Імпортувати до {calendar}",
     "Event imported into {calendar}" : "Подію імпортовано до {calendar}",
     "Could not create event" : "Неможливо створити подію",
@@ -161,9 +159,10 @@ OC.L10N.register(
     "Host" : "Хост",
     "Port" : "Порт",
     "SMTP" : "SMTP",
-    "Account settings" : "Налаштування облікового запису",
     "Change name" : "Змінити ім'я",
     "Mail server" : "Поштовий сервер",
+    "Keyboard shortcut" : "Сполучення клавіш",
+    "Keyboard shortcuts" : "Гарячі клавіші",
     "Compose new message" : "Нове повідомлення",
     "Newer message" : "Новіші повідомлення",
     "Older message" : "Старіші повідомлення",
@@ -186,6 +185,7 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n нове повідомлення\nвід {from}","%n нові повідомлення\nвід {from}","%n нових повідомлень\nвід {from}","%n нових повідомлень\nвід {from}"],
     "Nextcloud Mail" : "Пошта Nextcloud",
+    "Could not load your message" : "Неможливо завантажити повідомлення",
     "Could not load the desired message" : "Неможливо завантажити обране повідомлення",
     "Could not load the message" : "Неможливо завантажити повідомлення",
     "Error loading message" : "Помилка завантаження повідомлення.",
