@@ -8,18 +8,15 @@ OC.L10N.register(
     "None" : "Không có",
     "Save" : "Lưu",
     "Connect" : "Kết nối",
-    "Keyboard shortcuts" : "Phím tắt",
     "Upload attachment" : "Tải lên một đính kèm",
     "Go back" : "Quay lại",
     "Send" : "Gởi",
-    "Favorite" : "Ưa thích",
     "Select" : "Select",
     "Delete" : "Xóa",
     "Important" : "Quan trọng",
     "Favorites" : "Ưa thích",
     "Other" : "Khác",
-    "to" : "đến",
-    "Reply" : "Trả l",
+    "Attachments" : "Đính kèm",
     "Settings" : "Thiết lập",
     "Quota" : "Hạn ngạch",
     "Add folder" : "Add folder",
@@ -27,12 +24,16 @@ OC.L10N.register(
     "Loading …" : "Đang tải...",
     "Cancel" : "Hủy bỏ",
     "Mark all as read" : "Đánh dấu tất cả như đã ",
+    "Edit name" : "Sửa đổi tên",
     "Clear cache" : "Xóa bộ nhớ ",
+    "Delete folder" : "Xóa thư mục",
     "Signature" : "Chữ ký",
+    "Reply" : "Trả l",
     "General" : "Tổng hợp",
     "User" : "Người dùng",
     "Host" : "Máy chủ",
     "Port" : "Cổng",
+    "Keyboard shortcuts" : "Phím tắt",
     "Search" : "Tìm",
     "Refresh" : "Làm mới",
     "All" : "Tất cả",
