@@ -1,11 +1,12 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "邮件",
     "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
     "Updating account failed: " : "更新账号失败：",
     "Creating account failed: " : "创建账号失败：",
     "Embedded message %s" : "嵌入式消息 %s",
+    "Mails" : "邮件",
+    "Mail" : "邮件",
     "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
     "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
     "Auto" : "自动",
@@ -30,10 +31,11 @@ OC.L10N.register(
     "SMTP Password" : "SMTP 密码",
     "Save" : "保存",
     "Connect" : "连接",
+    "Add alias" : "添加别名",
     "Add mail account" : "添加邮件账号",
     "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
     "Register as application for mail links" : "注册为邮件链接应用",
-    "Keyboard shortcuts" : "键盘快捷方式",
+    "Show keyboard shortcuts" : "显示键盘快捷方式",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允许该应用收集有关您的互动的数据。 根据这些数据，该应用程序将适应您的偏好。 数据将仅存储在本地。",
     "From" : "发件人",
     "Select account" : "选择账号",
@@ -76,8 +78,6 @@ OC.L10N.register(
     "No messages in this folder" : "该文件夹内没有消息",
     "No messages" : "没有消息",
     "Draft: " : "草稿: ",
-    "Unfavorite" : "取消收藏",
-    "Favorite" : "收藏",
     "Mark unimportant" : "标记为不重要",
     "Mark important" : "标记为重要",
     "Mark unread" : "标记为未读",
@@ -93,6 +93,7 @@ OC.L10N.register(
     "Favorite " : "收藏",
     "Unselect " : "取消选择",
     "Delete " : "删除",
+    "Load more" : "加载更多",
     "Report this bug" : "报告此问题",
     "Could not open mailbox" : "无法打开邮箱",
     "Loading messages" : "正在加载消息",
@@ -100,15 +101,7 @@ OC.L10N.register(
     "Important" : "重要",
     "Favorites" : "收藏",
     "Other" : "其他",
-    "Not found" : "没有找到",
-    "to" : "收件人",
-    "cc" : "抄送",
-    "Reply" : "回复",
-    "Reply to sender only" : "只回复发送者",
-    "Forward" : "转发",
-    "View source" : "查看来源",
-    "Message source" : "消息来源",
-    "Could not load your message" : "无法加载您的消息",
+    "Attachments" : "附件",
     "Import into calendar" : "导入到日历",
     "Download attachment" : "下载附件",
     "Save to Files" : "保存到“文件”",
@@ -123,13 +116,15 @@ OC.L10N.register(
     "New message" : "新建消息",
     "Settings" : "设置",
     "Quota" : "配额",
-    "Edit account" : "编辑账号",
+    "Account settings" : "账号设置",
     "Show only subscribed folders" : "仅显示已订阅的文件夹",
     "Add folder" : "添加文件夹",
-    "Move Up" : "上移",
+    "Saving" : "正在保存",
     "Move down" : "下移",
     "Remove account" : "移除账号",
     "Loading …" : "正在加载...",
+    "Not supported by the server" : "服务器不支持",
+    "{usage} of {limit} used" : "已使用{usage} / {limit}",
     "Remove account {email}" : "移除账号 {email}",
     "Remove {email}" : "移除 {email}",
     "Cancel" : "取消",
@@ -137,11 +132,13 @@ OC.L10N.register(
     "Show all folders" : "显示全部文件夹",
     "Collapse folders" : "折叠文件夹",
     "Mark all as read" : "标记所有为已读",
-    "Mark all messages of this folder as read" : "将此文件夹中的所有消息都标记为已读",
     "Add subfolder" : "添加子文件夹",
+    "Edit name" : "编辑名称",
     "Clear cache" : "清空缓存",
     "Clear locally cached data, in case there are issues with synchronization." : "万一同步出现问题，请清除本地缓存的数据。",
+    "Delete folder" : "删除文件夹",
     "_{total} message_::_{total} messages_" : ["{total} 条消息"],
+    "Not found" : "没有找到",
     "Could not load your draft" : "无法加载您的草稿",
     "Could not load original message" : "无法加载初始消息",
     "No message selected" : "没有选择消息",
@@ -149,6 +146,11 @@ OC.L10N.register(
     "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
     "Signature …" : "签名...",
     "Save signature" : "保存签名",
+    "Reply" : "回复",
+    "Reply to sender only" : "只回复发送者",
+    "Forward" : "转发",
+    "View source" : "查看来源",
+    "Message source" : "消息来源",
     "Import into {calendar}" : "导入到 {calendar}",
     "Event imported into {calendar}" : "事件导入到 {calendar}",
     "Could not create event" : "无法建立事件",
@@ -174,9 +176,10 @@ OC.L10N.register(
     "Apply and create/update for all users" : "为所有用户应用并 创建 / 更新",
     "Disable and un-provision existing accounts" : "禁用和取消设置现有账号",
     "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
-    "Account settings" : "账号设置",
     "Change name" : "更改名称",
     "Mail server" : "邮件服务器",
+    "Keyboard shortcut" : "键盘快捷键",
+    "Keyboard shortcuts" : "键盘快捷方式",
     "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
     "Compose new message" : "撰写新消息",
     "Newer message" : "更新的信息",
@@ -203,6 +206,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud 邮件",
     "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
+    "Could not load your message" : "无法加载您的消息",
     "Could not load the desired message" : "无法加载想要的消息",
     "Could not load the message" : "无法加载该消息",
     "Error loading message" : "载入消息时发生错误",
