@@ -15,12 +15,12 @@ OC.L10N.register(
     "Important" : "重要",
     "Favorites" : "最愛",
     "Other" : "其他",
-    "to" : "至",
-    "Reply" : "回覆",
     "Settings" : "設定",
     "Add folder" : "Add folder",
+    "Saving" : "儲存中",
     "Cancel" : "取消",
     "Signature" : "署名",
+    "Reply" : "回覆",
     "General" : "一般",
     "User" : "User",
     "Host" : "主機",
