@@ -1,10 +1,10 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "電子郵件",
     "Auto detect failed. Please use manual mode." : "自動偵測失敗，請改用手動輸入",
     "Updating account failed: " : "更新帳戶失敗",
     "Creating account failed: " : "建立帳號失敗：",
+    "Mail" : "電子郵件",
     "Auto" : "自動",
     "Name" : "名字",
     "Mail Address" : "郵件地址",
@@ -29,7 +29,6 @@ OC.L10N.register(
     "Connect" : "連線",
     "Add mail account" : "新增郵件帳戶",
     "Use Gravatar and favicon avatars" : "使用個人化大頭貼與網站圖示",
-    "Keyboard shortcuts" : "快速鍵",
     "Select account" : "選擇帳號",
     "Subject" : "主旨",
     "Upload attachment" : "上傳附件",
@@ -42,19 +41,13 @@ OC.L10N.register(
     "Send" : "傳送",
     "Choose a file to add as attachment" : "選擇檔案作為附件",
     "No messages in this folder" : "此收件匣中沒有信件",
-    "Unfavorite" : "取消我的最愛",
-    "Favorite" : "我的最愛",
     "Unselect" : "取消選取",
     "Select" : "選取",
     "Delete" : "刪除",
     "Important" : "重要",
     "Favorites" : "我的最愛",
     "Other" : "其他",
-    "to" : "至",
-    "cc" : "副本",
-    "Reply" : "回覆",
-    "Forward" : "向前",
-    "Could not load your message" : "無法載入您的信件",
+    "Attachments" : "附件",
     "Import into calendar" : "匯入到日曆",
     "Download attachment" : "下載附檔",
     "Save to Files" : "儲存至雲端檔案",
@@ -67,18 +60,26 @@ OC.L10N.register(
     "Settings" : "設定",
     "Quota" : "用量",
     "Add folder" : "新增資料夾",
+    "Saving" : "儲存中...",
     "Remove account" : "移除帳號",
     "Loading …" : "載入中 ...",
     "Cancel" : "取消",
     "Show all folders" : "顯示所有收件匣",
     "Collapse folders" : "收合收件匣",
     "Mark all as read" : "全部標示為已閱讀",
+    "Edit name" : "編輯名稱",
     "Clear cache" : "清除快取",
+    "Delete folder" : "刪除資料夾",
     "Signature" : "簽章",
+    "Reply" : "回覆",
+    "Forward" : "向前",
     "General" : "一般",
     "User" : "使用者",
     "Host" : "主機",
     "Port" : "連接埠",
+    "Change name" : "更改名稱",
+    "Keyboard shortcut" : "快速鍵",
+    "Keyboard shortcuts" : "快速鍵",
     "Speed up your Mail experience with these quick shortcuts." : "使用快速鍵來加速您的操作體驗",
     "Compose new message" : "撰寫新信件",
     "Newer message" : "較新的信件",
@@ -101,6 +102,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Nextcloud 郵件",
     "Could not load {tag}{name}{endtag}" : "無法載入 {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "載入 {tag}{name}{endtag} 時出現問題",
+    "Could not load your message" : "無法載入您的信件",
     "Could not load the desired message" : "無法載入所選的信件",
     "Could not load the message" : "無法載入信件",
     "Error loading message" : "載入信件錯誤",
