@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 /**
  * @copyright 2017 Christoph Wurst <christoph@winzerhof-wurst.at>
  *
@@ -60,15 +62,21 @@ class AddressList implements Countable, JsonSerializable {
 	 * @return AddressList
 	 */
 	public static function fromHorde(Horde_Mail_Rfc822_List $hordeList) {
-		$addresses = array_map(function(Horde_Mail_Rfc822_Address $addr) {
+		$addresses = array_map(function (Horde_Mail_Rfc822_Address $addr) {
 			return new Address($addr->personal, $addr->bare_address);
-		}, array_filter(iterator_to_array($hordeList), function(Horde_Mail_Rfc822_Object $obj) {
-				// TODO: how to handle non-addresses? This doesn't seem right …
-				return $obj instanceof Horde_Mail_Rfc822_Address;
-			}));
+		}, array_filter(iterator_to_array($hordeList), function (Horde_Mail_Rfc822_Object $obj) {
+			// TODO: how to handle non-addresses? This doesn't seem right …
+			return $obj instanceof Horde_Mail_Rfc822_Address;
+		}));
 		return new AddressList($addresses);
 	}
 
+	public static function fromRow(array $recipient): self {
+		return new self([
+			new Address($recipient['label'], $recipient['email'])
+		]);
+	}
+
 	/**
 	 * Get first element
 	 *
@@ -88,7 +96,7 @@ class AddressList implements Countable, JsonSerializable {
 	 * @return array
 	 */
 	public function jsonSerialize() {
-		return array_map(function(Address $address) {
+		return array_map(function (Address $address) {
 			return $address->jsonSerialize();
 		}, $this->addresses);
 	}
@@ -102,8 +110,12 @@ class AddressList implements Countable, JsonSerializable {
 
 	/**
 	 * Iterate over the internal list of addresses using a generator method
+	 *
+	 * @return \Generator
+	 *
+	 * @psalm-return \Generator<int, Address, mixed, void>
 	 */
-	public function iterate() {
+	public function iterate(): \Generator {
 		foreach ($this->addresses as $address) {
 			yield $address;
 		}
@@ -116,8 +128,8 @@ class AddressList implements Countable, JsonSerializable {
 	public function merge(AddressList $other) {
 		$addresses = $this->addresses;
 
-		array_walk($other->addresses, function(Address $address) use (&$addresses) {
-			$same = array_filter($addresses, function(Address $our) use ($address) {
+		array_walk($other->addresses, function (Address $address) use (&$addresses) {
+			$same = array_filter($addresses, function (Address $our) use ($address) {
 				// Check whether our array contains the other address
 				return $our->equals($address);
 			});
@@ -135,10 +147,9 @@ class AddressList implements Countable, JsonSerializable {
 	 * @return Horde_Mail_Rfc822_List
 	 */
 	public function toHorde() {
-		$hordeAddresses = array_map(function(Address $address) {
+		$hordeAddresses = array_map(function (Address $address) {
 			return $address->toHorde();
 		}, $this->addresses);
 		return new Horde_Mail_Rfc822_List($hordeAddresses);
 	}
-
 }
