@@ -29,8 +29,10 @@ use OCA\Mail\Account;
 use OCA\Mail\Exception\IncompleteSyncException;
 use OCA\Mail\Exception\ServiceException;
 use OCA\Mail\IMAP\MailboxSync;
+use OCA\Mail\Integration\Psr\LoggerAdapter;
 use OCA\Mail\Service\AccountService;
 use OCA\Mail\Service\Sync\ImapToDbSynchronizer;
+use OCA\Mail\Support\ConsoleLoggerDecorator;
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputArgument;
 use Symfony\Component\Console\Input\InputInterface;
@@ -51,14 +53,19 @@ class SyncAccount extends Command {
 	/** @var ImapToDbSynchronizer */
 	private $syncService;
 
+	/** @var LoggerAdapter */
+	private $logger;
+
 	public function __construct(AccountService $service,
 								MailboxSync $mailboxSync,
-								ImapToDbSynchronizer $messageSync) {
+								ImapToDbSynchronizer $messageSync,
+								LoggerAdapter $logger) {
 		parent::__construct();
 
 		$this->accountService = $service;
 		$this->mailboxSync = $mailboxSync;
 		$this->syncService = $messageSync;
+		$this->logger = $logger;
 	}
 
 	/**
@@ -71,10 +78,7 @@ class SyncAccount extends Command {
 		$this->addOption(self::OPTION_FORCE, 'f', InputOption::VALUE_NONE);
 	}
 
-	/**
-	 * @return void
-	 */
-	protected function execute(InputInterface $input, OutputInterface $output) {
+	protected function execute(InputInterface $input, OutputInterface $output): int {
 		$accountId = (int)$input->getArgument(self::ARGUMENT_ACCOUNT_ID);
 		$force = $input->getOption(self::OPTION_FORCE);
 
@@ -84,14 +88,21 @@ class SyncAccount extends Command {
 
 		$mbs = (int)(memory_get_peak_usage() / 1024 / 1024);
 		$output->writeln('<info>' . $mbs . 'MB of memory used</info>');
+
+		return 0;
 	}
 
 	private function sync(Account $account, bool $force, OutputInterface $output) {
+		$consoleLogger = new ConsoleLoggerDecorator(
+			$this->logger,
+			$output
+		);
+
 		try {
-			$this->mailboxSync->sync($account, $force);
-			$this->syncService->syncAccount($account, $force);
+			$this->mailboxSync->sync($account, $consoleLogger, $force);
+			$this->syncService->syncAccount($account, $consoleLogger, $force);
 		} catch (ServiceException $e) {
-			if (!($e->getPrevious() instanceof IncompleteSyncException)) {
+			if (!($e instanceof IncompleteSyncException)) {
 				throw $e;
 			}
 
