@@ -24,6 +24,7 @@ declare(strict_types=1);
 namespace OCA\Mail\Contracts;
 
 use OCA\Mail\Db\Alias;
+use OCA\Mail\Db\Message;
 use OCA\Mail\Exception\ServiceException;
 use OCA\Mail\Model\NewMessageData;
 use OCA\Mail\Model\RepliedMessageData;
@@ -33,27 +34,27 @@ interface IMailTransmission {
 	/**
 	 * Send a new message or reply to an existing one
 	 *
-	 * @param string $userId
 	 * @param NewMessageData $message
-	 * @param RepliedMessageData $reply
+	 * @param RepliedMessageData|null $reply
 	 * @param Alias|null $alias
+	 * @param Message|null $draft
 	 *
 	 * @throws ServiceException
 	 */
 	public function sendMessage(NewMessageData $message,
 								RepliedMessageData $reply = null,
 								Alias $alias = null,
-								int $draftUID = null);
+								Message $draft = null);
 
 	/**
 	 * Save a message draft
 	 *
 	 * @param NewMessageData $message
-	 * @param int $draftUID
+	 * @param Message|null $previousDraft
 	 *
-	 * @return int
+	 * @return array
 	 *
 	 * @throws ServiceException
 	 */
-	public function saveDraft(NewMessageData $message, int $draftUID = null): int;
+	public function saveDraft(NewMessageData $message, Message $previousDraft = null): array;
 }
