@@ -116,14 +116,14 @@ class PageController extends Controller {
 			$json['aliases'] = $this->aliasesService->findAll($mailAccount->getId(),
 				$this->currentUserId);
 			try {
-				$folders = $this->mailManager->getFolders($mailAccount);
-				$json['folders'] = $folders;
+				$mailboxes = $this->mailManager->getMailboxes($mailAccount);
+				$json['mailboxes'] = $mailboxes;
 			} catch (Exception $ex) {
 				$this->logger->logException($ex, [
-					'message' => 'Could not load account folders: ' . $ex->getMessage(),
+					'message' => 'Could not load account mailboxes: ' . $ex->getMessage(),
 					'level' => ILogger::FATAL,
 				]);
-				$json['folders'] = [];
+				$json['mailboxes'] = [];
 				$json['error'] = true;
 			}
 			$accountsJson[] = $json;
@@ -156,6 +156,46 @@ class PageController extends Controller {
 		return $response;
 	}
 
+	/**
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
+	 *
+	 * @return TemplateResponse
+	 */
+	public function setup(): TemplateResponse {
+		return $this->index();
+	}
+
+	/**
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
+	 *
+	 * @return TemplateResponse
+	 */
+	public function accountSettings(int $id): TemplateResponse {
+		return $this->index();
+	}
+
+	/**
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
+	 *
+	 * @return TemplateResponse
+	 */
+	public function mailbox(int $id): TemplateResponse {
+		return $this->index();
+	}
+
+	/**
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
+	 *
+	 * @return TemplateResponse
+	 */
+	public function thread(int $mailboxId, int $id): TemplateResponse {
+		return $this->index();
+	}
+
 	/**
 	 * @NoAdminRequired
 	 * @NoCSRFRequired
