@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 
 /**
@@ -47,6 +48,8 @@ class MailAccountMapper extends QBMapper {
 	 * @param int $accountId
 	 *
 	 * @return MailAccount
+	 *
+	 * @throws DoesNotExistException
 	 */
 	public function find(string $userId, int $accountId): MailAccount {
 		$qb = $this->db->getQueryBuilder();
@@ -60,7 +63,7 @@ class MailAccountMapper extends QBMapper {
 	}
 
 	/**
-	 * @param int $id
+	 * Finds an mail account by id
 	 *
 	 * @return MailAccount
 	 * @throws DoesNotExistException
@@ -134,4 +137,12 @@ class MailAccountMapper extends QBMapper {
 		$delete->execute();
 	}
 
+	public function getAllAccounts(): array {
+		$qb = $this->db->getQueryBuilder();
+		$query = $qb
+			->select('*')
+			->from($this->getTableName());
+
+		return $this->findEntities($query);
+	}
 }
