@@ -26,16 +26,22 @@ declare(strict_types=1);
 namespace OCA\Mail\Db;
 
 use Horde_Imap_Client;
+use OCA\Mail\Account;
 use OCA\Mail\Address;
 use OCA\Mail\AddressList;
+use OCA\Mail\IMAP\Threading\DatabaseMessage;
 use OCA\Mail\Service\Search\SearchQuery;
+use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\QBMapper;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
+use OCP\IUser;
 use function array_combine;
 use function array_keys;
 use function array_map;
+use function in_array;
+use function ltrim;
 use function mb_substr;
 
 class MessageMapper extends QBMapper {
@@ -49,6 +55,11 @@ class MessageMapper extends QBMapper {
 		$this->timeFactory = $timeFactory;
 	}
 
+	/**
+	 * @param IQueryBuilder $query
+	 *
+	 * @return int[]
+	 */
 	private function findUids(IQueryBuilder $query): array {
 		$result = $query->execute();
 		$uids = array_map(function (array $row) {
@@ -59,6 +70,21 @@ class MessageMapper extends QBMapper {
 		return $uids;
 	}
 
+	/**
+	 * @param IQueryBuilder $query
+	 *
+	 * @return int[]
+	 */
+	private function findIds(IQueryBuilder $query): array {
+		$result = $query->execute();
+		$uids = array_map(function (array $row) {
+			return (int)$row['id'];
+		}, $result->fetchAll());
+		$result->closeCursor();
+
+		return $uids;
+	}
+
 	public function findHighestUid(Mailbox $mailbox): ?int {
 		$query = $this->db->getQueryBuilder();
 
@@ -76,16 +102,128 @@ class MessageMapper extends QBMapper {
 		return $max;
 	}
 
+	public function findByUserId(string $uid, int $id): Message {
+		$query = $this->db->getQueryBuilder();
+
+		$query->select('m.*')
+			->from($this->getTableName(), 'm')
+			->join('m', 'mail_mailboxes', 'mb', $query->expr()->eq('m.mailbox_id', 'mb.id', IQueryBuilder::PARAM_INT))
+			->join('m', 'mail_accounts', 'a', $query->expr()->eq('mb.account_id', 'a.id', IQueryBuilder::PARAM_INT))
+			->where(
+				$query->expr()->eq('a.user_id', $query->createNamedParameter($uid)),
+				$query->expr()->eq('m.id', $query->createNamedParameter($id, IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT)
+			);
+
+		$results = $this->findRecipients($this->findEntities($query));
+		if (empty($results)) {
+			throw new DoesNotExistException("Message $id does not exist");
+		}
+		return $results[0];
+	}
+
 	public function findAllUids(Mailbox $mailbox): array {
 		$query = $this->db->getQueryBuilder();
 
 		$query->select('uid')
 			->from($this->getTableName())
-			->where($query->expr()->eq('mailbox_id', $query->createNamedParameter($mailbox->getId())));
+			->where($query->expr()->eq('mailbox_id', $query->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT));
 
 		return $this->findUids($query);
 	}
 
+	public function findAllIds(Mailbox $mailbox): array {
+		$query = $this->db->getQueryBuilder();
+
+		$query->select('id')
+			->from($this->getTableName())
+			->where($query->expr()->eq('mailbox_id', $query->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT));
+
+		return $this->findIds($query);
+	}
+
+	/**
+	 * @param Mailbox $mailbox
+	 * @param int[] $ids
+	 *
+	 * @return int[]
+	 */
+	public function findUidsForIds(Mailbox $mailbox, array $ids) {
+		if (empty($ids)) {
+			// Shortcut for empty sets
+			return [];
+		}
+
+		$query = $this->db->getQueryBuilder();
+		$query->select('uid')
+			->from($this->getTableName())
+			->where(
+				$query->expr()->eq('mailbox_id', $query->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT),
+				$query->expr()->in('id', $query->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY)
+			);
+
+		return $this->findUids($query);
+	}
+
+	/**
+	 * @param Account $account
+	 *
+	 * @return DatabaseMessage[]
+	 */
+	public function findThreadingData(Account $account): array {
+		$mailboxesQuery = $this->db->getQueryBuilder();
+		$messagesQuery = $this->db->getQueryBuilder();
+
+		$mailboxesQuery->select('id')
+			->from('mail_mailboxes')
+			->where($mailboxesQuery->expr()->eq('account_id', $messagesQuery->createNamedParameter($account->getId(), IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT));
+		$messagesQuery->select('id', 'subject', 'message_id', 'in_reply_to', 'references', 'thread_root_id')
+			->from($this->getTableName())
+			->where($messagesQuery->expr()->in('mailbox_id', $messagesQuery->createFunction($mailboxesQuery->getSQL()), IQueryBuilder::PARAM_INT_ARRAY))
+			->andWhere($messagesQuery->expr()->isNotNull('message_id'));
+
+		$result = $messagesQuery->execute();
+		$messages = array_map(function (array $row) {
+			return DatabaseMessage::fromRowData(
+				(int)$row['id'],
+				$row['subject'],
+				$row['message_id'],
+				$row['references'],
+				$row['in_reply_to'],
+				$row['thread_root_id']
+			);
+		}, $result->fetchAll());
+		$result->closeCursor();
+
+		return $messages;
+	}
+
+	/**
+	 * @param DatabaseMessage[] $messages
+	 *
+	 * @todo combine threads and send just one query per thread, like UPDATE ... SET thread_root_id = xxx where UID IN (...)
+	 */
+	public function writeThreadIds(array $messages): void {
+		$this->db->beginTransaction();
+
+		$query = $this->db->getQueryBuilder();
+		$query->update($this->getTableName())
+			->set('thread_root_id', $query->createParameter('thread_root_id'))
+			->where($query->expr()->eq('id', $query->createParameter('id')));
+
+		foreach ($messages as $message) {
+			$query->setParameter(
+				'thread_root_id',
+				$message->getThreadRootId(),
+				$message->getThreadRootId() === null ? IQueryBuilder::PARAM_NULL : IQueryBuilder::PARAM_STR
+			);
+			$query->setParameter('id', $message->getDatabaseId(), IQueryBuilder::PARAM_INT);
+
+			$query->execute();
+		}
+
+		$this->db->commit();
+	}
+
 	public function insertBulk(Message ...$messages): void {
 		$this->db->beginTransaction();
 
@@ -93,6 +231,9 @@ class MessageMapper extends QBMapper {
 		$qb1->insert($this->getTableName());
 		$qb1->setValue('uid', $qb1->createParameter('uid'));
 		$qb1->setValue('message_id', $qb1->createParameter('message_id'));
+		$qb1->setValue('references', $qb1->createParameter('references'));
+		$qb1->setValue('in_reply_to', $qb1->createParameter('in_reply_to'));
+		$qb1->setValue('thread_root_id', $qb1->createParameter('thread_root_id'));
 		$qb1->setValue('mailbox_id', $qb1->createParameter('mailbox_id'));
 		$qb1->setValue('subject', $qb1->createParameter('subject'));
 		$qb1->setValue('sent_at', $qb1->createParameter('sent_at'));
@@ -116,6 +257,12 @@ class MessageMapper extends QBMapper {
 		foreach ($messages as $message) {
 			$qb1->setParameter('uid', $message->getUid(), IQueryBuilder::PARAM_INT);
 			$qb1->setParameter('message_id', $message->getMessageId(), IQueryBuilder::PARAM_STR);
+			$inReplyTo = $message->getInReplyTo();
+			$qb1->setParameter('in_reply_to', $inReplyTo, $inReplyTo === null ? IQueryBuilder::PARAM_NULL : IQueryBuilder::PARAM_STR);
+			$references = $message->getReferences();
+			$qb1->setParameter('references', $references, $references === null ? IQueryBuilder::PARAM_NULL : IQueryBuilder::PARAM_STR);
+			$threadRootId = $message->getThreadRootId();
+			$qb1->setParameter('thread_root_id', $threadRootId, $threadRootId === null ? IQueryBuilder::PARAM_NULL : IQueryBuilder::PARAM_STR);
 			$qb1->setParameter('mailbox_id', $message->getMailboxId(), IQueryBuilder::PARAM_INT);
 			$qb1->setParameter('subject', $message->getSubject(), IQueryBuilder::PARAM_STR);
 			$qb1->setParameter('sent_at', $message->getSentAt(), IQueryBuilder::PARAM_INT);
@@ -268,6 +415,49 @@ class MessageMapper extends QBMapper {
 		$query->execute();
 	}
 
+	/**
+	 * @param Account $account
+	 * @param int $messageId
+	 *
+	 * @return Message[]
+	 */
+	public function findThread(Account $account, int $messageId): array {
+		$qb = $this->db->getQueryBuilder();
+		$subQb1 = $this->db->getQueryBuilder();
+		$subQb2 = $this->db->getQueryBuilder();
+
+		$mailboxIdsQuery = $subQb1
+			->select('id')
+			->from('mail_mailboxes')
+			->where($qb->expr()->eq('account_id', $qb->createNamedParameter($account->getId(), IQueryBuilder::PARAM_INT)));
+		$threadRootIdsQuery = $subQb2
+			->select('thread_root_id')
+			->from($this->getTableName())
+			->where(
+				$qb->expr()->eq('id', $qb->createNamedParameter($messageId, IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT)
+			);
+
+		/**
+		 * Select the message with the given ID or any that has the same thread ID
+		 */
+		$selectMessages = $qb
+			->select('*')
+			->from($this->getTableName())
+			->where(
+				$qb->expr()->in('mailbox_id', $qb->createFunction($mailboxIdsQuery->getSQL()), IQueryBuilder::PARAM_INT_ARRAY),
+				$qb->expr()->orX(
+					$qb->expr()->eq('id', $qb->createNamedParameter($messageId, IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT),
+					$qb->expr()->andX(
+						$qb->expr()->isNotNull('thread_root_id'),
+						$qb->expr()->in('thread_root_id', $qb->createFunction($threadRootIdsQuery->getSQL()), IQueryBuilder::PARAM_INT_ARRAY)
+					)
+				)
+			)
+			->orderBy('sent_at', 'desc');
+
+		return $this->findRecipients($this->findEntities($selectMessages));
+	}
+
 	/**
 	 * @param Mailbox $mailbox
 	 * @param SearchQuery $query
@@ -276,11 +466,11 @@ class MessageMapper extends QBMapper {
 	 *
 	 * @return int[]
 	 */
-	public function findUidsByQuery(Mailbox $mailbox, SearchQuery $query, ?int $limit, array $uids = null): array {
+	public function findIdsByQuery(Mailbox $mailbox, SearchQuery $query, ?int $limit, array $uids = null): array {
 		$qb = $this->db->getQueryBuilder();
 
 		$select = $qb
-			->selectDistinct('m.uid')
+			->selectDistinct('m.id')
 			->addSelect('m.sent_at')
 			->from($this->getTableName(), 'm');
 
@@ -322,12 +512,16 @@ class MessageMapper extends QBMapper {
 			);
 		}
 
-		if ($query->getSubject() !== null) {
+		if (!empty($query->getSubjects())) {
 			$select->andWhere(
-				$qb->expr()->iLike(
-					'subject',
-					$qb->createNamedParameter('%' . $this->db->escapeLikeParameter($query-> $query->getSubject()) . '%', IQueryBuilder::PARAM_STR),
-					IQueryBuilder::PARAM_STR
+				$qb->expr()->orX(
+					...array_map(function (string $subject) use ($qb) {
+						return $qb->expr()->iLike(
+							'subject',
+							$qb->createNamedParameter('%' . $this->db->escapeLikeParameter($subject) . '%', IQueryBuilder::PARAM_STR),
+							IQueryBuilder::PARAM_STR
+						);
+					}, $query->getSubjects())
 				)
 			);
 		}
@@ -371,7 +565,115 @@ class MessageMapper extends QBMapper {
 		}
 
 		return array_map(function (Message $message) {
-			return $message->getUid();
+			return $message->getId();
+		}, $this->findEntities($select));
+	}
+
+	public function findIdsGloballyByQuery(IUser $user, SearchQuery $query, ?int $limit, array $uids = null): array {
+		$qb = $this->db->getQueryBuilder();
+		$qbMailboxes = $this->db->getQueryBuilder();
+
+		$select = $qb
+			->selectDistinct('m.id')
+			->addSelect('m.sent_at')
+			->from($this->getTableName(), 'm');
+
+		if (!empty($query->getFrom())) {
+			$select->innerJoin('m', 'mail_recipients', 'r0', 'm.id = r0.message_id');
+		}
+		if (!empty($query->getTo())) {
+			$select->innerJoin('m', 'mail_recipients', 'r1', 'm.id = r1.message_id');
+		}
+		if (!empty($query->getCc())) {
+			$select->innerJoin('m', 'mail_recipients', 'r2', 'm.id = r2.message_id');
+		}
+		if (!empty($query->getBcc())) {
+			$select->innerJoin('m', 'mail_recipients', 'r3', 'm.id = r3.message_id');
+		}
+
+		$selectMailboxIds = $qbMailboxes->select('mb.id')
+			->from('mail_mailboxes', 'mb')
+			->join('mb', 'mail_accounts', 'a', $qb->expr()->eq('a.id', 'mb.account_id', IQueryBuilder::PARAM_INT))
+			->where($qb->expr()->eq('a.user_id', $qb->createNamedParameter($user->getUID())));
+		$select->where(
+			$qb->expr()->in('mailbox_id', $qb->createFunction($selectMailboxIds->getSQL()), IQueryBuilder::PARAM_INT_ARRAY)
+		);
+
+		if (!empty($query->getFrom())) {
+			$select->andWhere(
+				$qb->expr()->in('r0.email', $qb->createNamedParameter($query->getFrom(), IQueryBuilder::PARAM_STR_ARRAY))
+			);
+		}
+		if (!empty($query->getTo())) {
+			$select->andWhere(
+				$qb->expr()->in('r1.email', $qb->createNamedParameter($query->getTo(), IQueryBuilder::PARAM_STR_ARRAY))
+			);
+		}
+		if (!empty($query->getCc())) {
+			$select->andWhere(
+				$qb->expr()->in('r2.email', $qb->createNamedParameter($query->getCc(), IQueryBuilder::PARAM_STR_ARRAY))
+			);
+		}
+		if (!empty($query->getBcc())) {
+			$select->andWhere(
+				$qb->expr()->in('r3.email', $qb->createNamedParameter($query->getBcc(), IQueryBuilder::PARAM_STR_ARRAY))
+			);
+		}
+
+		if (!empty($query->getSubjects())) {
+			$select->andWhere(
+				$qb->expr()->orX(
+					...array_map(function (string $subject) use ($qb) {
+						return $qb->expr()->iLike(
+							'subject',
+							$qb->createNamedParameter('%' . $this->db->escapeLikeParameter($subject) . '%', IQueryBuilder::PARAM_STR),
+							IQueryBuilder::PARAM_STR
+						);
+					}, $query->getSubjects())
+				)
+			);
+		}
+
+		if ($query->getCursor() !== null) {
+			$select->andWhere(
+				$qb->expr()->lt('sent_at', $qb->createNamedParameter($query->getCursor(), IQueryBuilder::PARAM_INT))
+			);
+		}
+		if ($uids !== null) {
+			$select->andWhere(
+				$qb->expr()->in('uid', $qb->createNamedParameter($uids, IQueryBuilder::PARAM_INT_ARRAY))
+			);
+		}
+
+		$flags = $query->getFlags();
+		$flagKeys = array_keys($flags);
+		foreach ([
+			Horde_Imap_Client::FLAG_ANSWERED,
+			Horde_Imap_Client::FLAG_DELETED,
+			Horde_Imap_Client::FLAG_DRAFT,
+			Horde_Imap_Client::FLAG_FLAGGED,
+			Horde_Imap_Client::FLAG_RECENT,
+			Horde_Imap_Client::FLAG_SEEN,
+			Horde_Imap_Client::FLAG_FORWARDED,
+			Horde_Imap_Client::FLAG_JUNK,
+			Horde_Imap_Client::FLAG_NOTJUNK,
+			'\\important',
+		] as $flag) {
+			if (in_array($flag, $flagKeys, true)) {
+				$key = ltrim($flag, '\\');
+				$select->andWhere($qb->expr()->eq("flag_$key", $qb->createNamedParameter($flags[$flag], IQueryBuilder::PARAM_BOOL)));
+			}
+		}
+
+		$select = $select
+			->orderBy('sent_at', 'desc');
+
+		if ($limit !== null) {
+			$select = $select->setMaxResults($limit);
+		}
+
+		return array_map(function (Message $message) {
+			return $message->getId();
 		}, $this->findEntities($select));
 	}
 
@@ -396,6 +698,28 @@ class MessageMapper extends QBMapper {
 		return $this->findRecipients($this->findEntities($select));
 	}
 
+	/**
+	 * @param int[] $ids
+	 *
+	 * @return Message[]
+	 */
+	public function findByIds(array $ids): array {
+		if (empty($ids)) {
+			return [];
+		}
+		$qb = $this->db->getQueryBuilder();
+
+		$select = $qb
+			->select('*')
+			->from($this->getTableName())
+			->where(
+				$qb->expr()->in('id', $qb->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY)
+			)
+			->orderBy('sent_at', 'desc');
+
+		return $this->findRecipients($this->findEntities($select));
+	}
+
 	/**
 	 * @param Message[] $messages
 	 *
@@ -452,18 +776,26 @@ class MessageMapper extends QBMapper {
 	 *
 	 * @return Message[]
 	 */
-	public function findNewUids(Mailbox $mailbox, int $highest): array {
+	public function findNewIds(Mailbox $mailbox, array $ids): array {
 		$qb = $this->db->getQueryBuilder();
+		$sub = $this->db->getQueryBuilder();
 
+		$subSelect = $sub
+			->select($sub->func()->max('uid'))
+			->from($this->getTableName())
+			->where(
+				$sub->expr()->eq('mailbox_id', $qb->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
+				$sub->expr()->in('id', $qb->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY)
+			);
 		$select = $qb
-			->select('uid')
+			->select('id')
 			->from($this->getTableName())
 			->where(
 				$qb->expr()->eq('mailbox_id', $qb->createNamedParameter($mailbox->getId(), IQueryBuilder::PARAM_INT)),
-				$qb->expr()->gt('uid', $qb->createNamedParameter($highest, IQueryBuilder::PARAM_INT))
+				$qb->expr()->gt('uid', $qb->createFunction('(' . $subSelect->getSQL() . ')'), IQueryBuilder::PARAM_INT)
 			);
 
-		return $this->findUids($select);
+		return $this->findIds($select);
 	}
 
 	public function findChanged(Mailbox $mailbox, int $since): array {
@@ -538,4 +870,22 @@ class MessageMapper extends QBMapper {
 			->where($qb4->expr()->in('id', $qb4->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY), IQueryBuilder::PARAM_INT_ARRAY));
 		$recipientsQuery->execute();
 	}
+
+	public function getIdForUid(Mailbox $mailbox, $uid): ?int {
+		$qb = $this->db->getQueryBuilder();
+
+		$select = $qb
+			->select('m.id')
+			->from($this->getTableName(), 'm')
+			->where(
+				$qb->expr()->eq('mailbox_id', $qb->createNamedParameter($mailbox->getId()), IQueryBuilder::PARAM_INT),
+				$qb->expr()->eq('uid', $qb->createNamedParameter($uid, IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT)
+			);
+		$result = $select->execute();
+		$rows = $result->fetchAll();
+		if (empty($rows)) {
+			return null;
+		}
+		return (int) $rows[0]['id'];
+	}
 }
