@@ -109,7 +109,7 @@ class FolderMapper {
 		$mailboxes = array_map(function (Folder $folder) {
 			return $folder->getMailbox();
 		}, array_filter($folders, function (Folder $folder) {
-			return $folder->isSearchable();
+			return !in_array('\noselect', $folder->getAttributes());
 		}));
 
 		$status = $client->status($mailboxes);
@@ -139,6 +139,19 @@ class FolderMapper {
 		);
 	}
 
+	/**
+	 * @param Horde_Imap_Client_Socket $client
+	 * @param string $oldName
+	 * @param string $newName
+	 *
+	 * @throws Horde_Imap_Client_Exception
+	 */
+	public function renameFolder(Horde_Imap_Client_Socket $client,
+								 string $oldName,
+								 string $newName): void {
+		$client->renameMailbox($oldName, $newName);
+	}
+
 	/**
 	 * @param Folder[] $folders
 	 *
@@ -219,4 +232,17 @@ class FolderMapper {
 			}
 		}
 	}
+
+	/**
+	 * @param Horde_Imap_Client_Socket $client
+	 * @param string $folderId
+	 * @throws ServiceException
+	 */
+	public function delete(Horde_Imap_Client_Socket $client, string $folderId): void {
+		try {
+			$client->deleteMailbox($folderId);
+		} catch (Horde_Imap_Client_Exception $e) {
+			throw new ServiceException('Could not delete mailbox: '.$e->getMessage(), 0, $e);
+		}
+	}
 }
