@@ -1,4 +1,6 @@
-<?php declare(strict_types=1);
+<?php
+
+declare(strict_types=1);
 
 /**
  * @copyright 2019 Christoph Wurst <christoph@winzerhof-wurst.at>
@@ -28,6 +30,7 @@ use Horde_Imap_Client_Exception;
 use OCA\Mail\Account;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Db\MailboxMapper;
+use OCA\Mail\Db\Message;
 use OCA\Mail\Events\DraftSavedEvent;
 use OCA\Mail\Events\MessageSentEvent;
 use OCA\Mail\IMAP\IMAPClientFactory;
@@ -36,7 +39,7 @@ use OCA\Mail\IMAP\MessageMapper;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
-use OCP\ILogger;
+use Psr\Log\LoggerInterface;
 
 class DeleteDraftListener implements IEventListener {
 
@@ -52,14 +55,14 @@ class DeleteDraftListener implements IEventListener {
 	/** @var MailboxSync */
 	private $mailboxSync;
 
-	/** @var ILogger */
+	/** @var LoggerInterface */
 	private $logger;
 
 	public function __construct(IMAPClientFactory $imapClientFactory,
 								MailboxMapper $mailboxMapper,
 								MessageMapper $messageMapper,
 								MailboxSync $mailboxSync,
-								ILogger $logger) {
+								LoggerInterface $logger) {
 		$this->imapClientFactory = $imapClientFactory;
 		$this->mailboxMapper = $mailboxMapper;
 		$this->messageMapper = $messageMapper;
@@ -68,17 +71,18 @@ class DeleteDraftListener implements IEventListener {
 	}
 
 	public function handle(Event $event): void {
-		if ($event instanceof DraftSavedEvent && $event->getDraftUid() !== null) {
-			$this->deleteDraft($event->getAccount(), $event->getDraftUid());
-		} else if ($event instanceof MessageSentEvent && $event->getDraftUid() !== null) {
-			$this->deleteDraft($event->getAccount(), $event->getDraftUid());
+		if ($event instanceof DraftSavedEvent && $event->getDraft() !== null) {
+			$this->deleteDraft($event->getAccount(), $event->getDraft());
+		} elseif ($event instanceof MessageSentEvent && $event->getDraft() !== null) {
+			$this->deleteDraft($event->getAccount(), $event->getDraft());
 		}
 	}
 
 	/**
-	 * @param DraftSavedEvent $event
+	 * @param Account $account
+	 * @param Message $draft
 	 */
-	private function deleteDraft(Account $account, int $draftUid): void {
+	private function deleteDraft(Account $account, Message $draft): void {
 		$client = $this->imapClientFactory->getClient($account);
 		$draftsMailbox = $this->getDraftsMailbox($account);
 
@@ -86,20 +90,20 @@ class DeleteDraftListener implements IEventListener {
 			$this->messageMapper->addFlag(
 				$client,
 				$draftsMailbox,
-				$draftUid,
+				$draft->getUid(), // TODO: the UID could be from another mailbox
 				Horde_Imap_Client::FLAG_DELETED
 			);
 		} catch (Horde_Imap_Client_Exception $e) {
-			$this->logger->logException($e, [
-				'message' => 'Could not flag draft as deleted'
+			$this->logger->error('Could not flag draft as deleted', [
+				'exception' => $e,
 			]);
 		}
 
 		try {
 			$client->expunge($draftsMailbox->getName());
 		} catch (Horde_Imap_Client_Exception $e) {
-			$this->logger->logException($e, [
-				'message' => 'Could not expunge drafts folder'
+			$this->logger->error('Could not expunge drafts folder', [
+				'exception' => $e,
 			]);
 		}
 	}
@@ -130,13 +134,12 @@ class DeleteDraftListener implements IEventListener {
 				]
 			);
 		} catch (Horde_Imap_Client_Exception $e) {
-			$this->logger->logException($e, [
-				'message' => 'Could not create drafts mailbox',
+			$this->logger->error('Could not create drafts mailbox', [
+				'exception' => $e,
 			]);
 		}
 
 		// TODO: find a more elegant solution for updating the mailbox cache
-		$this->mailboxSync->sync($account, true);
+		$this->mailboxSync->sync($account, $this->logger,true);
 	}
-
 }
