@@ -38,6 +38,7 @@ use Horde_Imap_Client_Fetch_Query;
 use Horde_Imap_Client_Ids;
 use Horde_Imap_Client_Mailbox;
 use Horde_Imap_Client_Socket;
+use Horde_Mime_Headers;
 use Horde_Mime_Part;
 use JsonSerializable;
 use OC;
@@ -47,7 +48,6 @@ use OCA\Mail\Service\Html;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\Files\File;
 use OCP\Files\SimpleFS\ISimpleFile;
-use function base64_encode;
 use function in_array;
 use function mb_convert_encoding;
 
@@ -163,6 +163,20 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		return $this->fetch->getEnvelope();
 	}
 
+	private function getRawReferences(): string {
+		/** @var Horde_Mime_Headers $headers */
+		$headers = $this->fetch->getHeaders('references', Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
+		$header = $headers->getHeader('references');
+		if ($header === null) {
+			return '';
+		}
+		return $header->value_single;
+	}
+
+	private function getRawInReplyTo(): string {
+		return $this->fetch->getEnvelope()->in_reply_to;
+	}
+
 	/**
 	 * @return AddressList
 	 */
@@ -407,15 +421,17 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	}
 
 	/**
+	 * @param int $id
+	 *
 	 * @return array
 	 */
-	public function getFullMessage(int $accountId, string $mailbox, int $id): array {
+	public function getFullMessage(int $id): array {
 		$mailBody = $this->plainMessage;
 
 		$data = $this->jsonSerialize();
 		if ($this->hasHtmlMessage) {
 			$data['hasHtmlBody'] = true;
-			$data['body'] = $this->getHtmlBody($accountId, $mailbox, $id);
+			$data['body'] = $this->getHtmlBody($id);
 		} else {
 			$mailBody = $this->htmlService->convertLinks($mailBody);
 			list($mailBody, $signature) = $this->htmlService->parseMailBody($mailBody);
@@ -433,7 +449,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	 */
 	public function jsonSerialize(): array {
 		return [
-			'id' => $this->getUid(),
+			'uid' => $this->getUid(),
 			'messageId' => $this->getMessageId(),
 			'from' => $this->getFrom()->jsonSerialize(),
 			'to' => $this->getTo()->jsonSerialize(),
@@ -447,17 +463,13 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	}
 
 	/**
-	 * @param int $accountId
-	 * @param string $folderId
-	 * @param int $messageId
+	 * @param int $id
 	 *
 	 * @return string
 	 */
-	public function getHtmlBody(int $accountId, string $folderId, int $messageId): string {
+	public function getHtmlBody(int $id): string {
 		return $this->htmlService->sanitizeHtmlMailBody($this->htmlMessage, [
-			'accountId' => $accountId,
-			'folderId' => base64_encode($folderId),
-			'messageId' => $messageId,
+			'id' => $id,
 		], function ($cid) {
 			$match = array_filter($this->attachments,
 				function ($a) use ($cid) {
@@ -630,6 +642,9 @@ class IMAPMessage implements IMessage, JsonSerializable {
 
 		$msg->setUid($this->getUid());
 		$msg->setMessageId($this->getMessageId());
+		$msg->setRawReferences($this->getRawReferences());
+		$msg->setThreadRootId($this->getMessageId());
+		$msg->setInReplyTo($this->getRawInReplyTo());
 		$msg->setMailboxId($mailboxId);
 		$msg->setFrom($this->getFrom());
 		$msg->setTo($this->getTo());
