@@ -23,7 +23,6 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Model;
 
-use Horde_Mail_Rfc822_List;
 use OCA\Mail\Account;
 use OCA\Mail\AddressList;
 
@@ -91,7 +90,7 @@ class NewMessageData {
 	 * @param string|null $bcc
 	 * @param string $subject
 	 * @param string $body
-	 * @param array|null $attachments
+	 * @param array $attachments
 	 *
 	 * @return NewMessageData
 	 */
@@ -163,5 +162,4 @@ class NewMessageData {
 	public function isHtml(): bool {
 		return $this->isHtml;
 	}
-
 }
