@@ -31,6 +31,7 @@ use OCA\Mail\Db\MailAccount;
 use OCA\Mail\Db\MailAccountMapper;
 use OCA\Mail\Exception\ClientException;
 use OCA\Mail\Exception\ServiceException;
+use OCA\mail\lib\Service\Quota;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\BackgroundJob\IJobList;
 use function array_map;
@@ -88,25 +89,25 @@ class AccountService {
 
 	/**
 	 * @param string $uid
-	 * @param int $accountId
+	 * @param int $id
 	 *
 	 * @return Account
 	 * @throws ClientException
 	 */
-	public function find(string $uid, int $accountId): Account {
+	public function find(string $uid, int $id): Account {
 		if ($this->accounts !== null) {
 			foreach ($this->accounts as $account) {
-				if ($account->getId() === $accountId) {
+				if ($account->getId() === $id) {
 					return $account;
 				}
 			}
-			throw new ClientException("Account $accountId does not exist or you don\'t have permission to access it");
+			throw new ClientException("Account $id does not exist or you don\'t have permission to access it");
 		}
 
 		try {
-			return new Account($this->mapper->find($uid, $accountId));
+			return new Account($this->mapper->find($uid, $id));
 		} catch (DoesNotExistException $e) {
-			throw new ClientException("Account $accountId does not exist or you don\'t have permission to access it");
+			throw new ClientException("Account $id does not exist or you don\'t have permission to access it");
 		}
 	}
 
@@ -156,4 +157,7 @@ class AccountService {
 		$mailAccount->setSignature($signature);
 		$this->mapper->save($mailAccount);
 	}
+
+	public function getQuota(): Quota {
+	}
 }
