@@ -25,10 +25,13 @@ namespace OCA\Mail\Service;
 
 use Horde_Imap_Client;
 use Horde_Imap_Client_Exception;
+use Horde_Imap_Client_Exception_NoSupportExtension;
 use OCA\Mail\Account;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Db\MailboxMapper;
+use OCA\Mail\Db\Message;
+use OCA\Mail\Db\MessageMapper as DbMessageMapper;
 use OCA\Mail\Events\BeforeMessageDeletedEvent;
 use OCA\Mail\Events\MessageDeletedEvent;
 use OCA\Mail\Events\MessageFlaggedEvent;
@@ -39,10 +42,13 @@ use OCA\Mail\IMAP\FolderMapper;
 use OCA\Mail\IMAP\FolderStats;
 use OCA\Mail\IMAP\IMAPClientFactory;
 use OCA\Mail\IMAP\MailboxSync;
-use OCA\Mail\IMAP\MessageMapper;
+use OCA\Mail\IMAP\MessageMapper as ImapMessageMapper;
 use OCA\Mail\Model\IMAPMessage;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\EventDispatcher\IEventDispatcher;
+use Psr\Log\LoggerInterface;
+use function array_map;
+use function array_values;
 
 class MailManager implements IMailManager {
 
@@ -71,51 +77,65 @@ class MailManager implements IMailManager {
 	/** @var FolderMapper */
 	private $folderMapper;
 
-	/** @var MessageMapper */
-	private $messageMapper;
+	/** @var ImapMessageMapper */
+	private $imapMessageMapper;
+
+	/** @var DbMessageMapper */
+	private $dbMessageMapper;
 
 	/** @var IEventDispatcher */
 	private $eventDispatcher;
+	/**
+	 * @var LoggerInterface
+	 */
+	private $logger;
 
 	public function __construct(IMAPClientFactory $imapClientFactory,
 								MailboxMapper $mailboxMapper,
 								MailboxSync $mailboxSync,
 								FolderMapper $folderMapper,
-								MessageMapper $messageMapper,
-								IEventDispatcher $eventDispatcher) {
+								ImapMessageMapper $messageMapper,
+								DbMessageMapper $dbMessageMapper,
+								IEventDispatcher $eventDispatcher,
+								LoggerInterface $logger) {
 		$this->imapClientFactory = $imapClientFactory;
 		$this->mailboxMapper = $mailboxMapper;
 		$this->mailboxSync = $mailboxSync;
 		$this->folderMapper = $folderMapper;
-		$this->messageMapper = $messageMapper;
+		$this->imapMessageMapper = $messageMapper;
+		$this->dbMessageMapper = $dbMessageMapper;
 		$this->eventDispatcher = $eventDispatcher;
+		$this->logger = $logger;
+	}
+
+	public function getMailbox(string $uid, int $id): Mailbox {
+		try {
+			return $this->mailboxMapper->findByUid($id, $uid);
+		} catch (DoesNotExistException $e) {
+			throw new ClientException("Mailbox $id does not exist", 0, $e);
+		}
 	}
 
 	/**
 	 * @param Account $account
 	 *
-	 * @return Folder[]
+	 * @return Mailbox[]
 	 * @throws ServiceException
 	 */
-	public function getFolders(Account $account): array {
-		$this->mailboxSync->sync($account);
+	public function getMailboxes(Account $account): array {
+		$this->mailboxSync->sync($account, $this->logger);
 
-		return array_map(
-			function (Mailbox $mb) {
-				return $mb->toFolder();
-			},
-			$this->mailboxMapper->findAll($account)
-		);
+		return $this->mailboxMapper->findAll($account);
 	}
 
 	/**
 	 * @param Account $account
 	 * @param string $name
 	 *
-	 * @return Folder
+	 * @return Mailbox
 	 * @throws ServiceException
 	 */
-	public function createFolder(Account $account, string $name): Folder {
+	public function createMailbox(Account $account, string $name): Mailbox {
 		$client = $this->imapClientFactory->getClient($account);
 
 		$folder = $this->folderMapper->createFolder($client, $account, $name);
@@ -126,32 +146,35 @@ class MailManager implements IMailManager {
 		}
 		$this->folderMapper->detectFolderSpecialUse([$folder]);
 
-		$this->mailboxSync->sync($account, true);
+		$this->mailboxSync->sync($account, $this->logger,true);
 
-		return $folder;
+		return $this->mailboxMapper->find($account, $name);
 	}
 
 	/**
 	 * @param Account $account
-	 * @param string $folderId
+	 * @param Mailbox $mailbox
 	 *
 	 * @return FolderStats
+	 * @throws Horde_Imap_Client_Exception
 	 */
-	public function getFolderStats(Account $account, string $folderId): FolderStats {
+	public function getMailboxStats(Account $account, Mailbox $mailbox): FolderStats {
 		$client = $this->imapClientFactory->getClient($account);
 
-		return $this->folderMapper->getFoldersStatusAsObject($client, $folderId);
+		return $this->folderMapper->getFoldersStatusAsObject($client, $mailbox->getName());
 	}
 
-	public function getMessage(Account $account, string $mailbox, int $id, bool $loadBody = false): IMAPMessage {
+	public function getImapMessage(Account $account,
+								   Mailbox $mailbox,
+								   int $uid,
+								   bool $loadBody = false): IMAPMessage {
 		$client = $this->imapClientFactory->getClient($account);
-		$mailbox = $this->mailboxMapper->find($account, $mailbox);
 
 		try {
-			return $this->messageMapper->find(
+			return $this->imapMessageMapper->find(
 				$client,
 				$mailbox->getName(),
-				$id,
+				$uid,
 				$loadBody
 			);
 		} catch (Horde_Imap_Client_Exception|DoesNotExistException $e) {
@@ -159,24 +182,36 @@ class MailManager implements IMailManager {
 		}
 	}
 
+	public function getThread(Account $account, int $messageId): array {
+		return $this->dbMessageMapper->findThread($account, $messageId);
+	}
+
+	public function getMessageIdForUid(Mailbox $mailbox, $uid): ?int {
+		return $this->dbMessageMapper->getIdForUid($mailbox, $uid);
+	}
+
+	public function getMessage(string $uid, int $id): Message {
+		return $this->dbMessageMapper->findByUserId($uid, $id);
+	}
+
 	/**
 	 * @param Account $account
 	 * @param string $mb
-	 * @param int $id
+	 * @param int $uid
 	 *
 	 * @return string
 	 *
 	 * @throws ClientException
 	 * @throws ServiceException
 	 */
-	public function getSource(Account $account, string $mailbox, int $id): string {
+	public function getSource(Account $account, string $mailbox, int $uid): ?string {
 		$client = $this->imapClientFactory->getClient($account);
 
 		try {
-			return $this->messageMapper->getSource(
+			return $this->imapMessageMapper->getSource(
 				$client,
 				$mailbox,
-				$id
+				$uid
 			);
 		} catch (Horde_Imap_Client_Exception|DoesNotExistException $e) {
 			throw new ServiceException("Could not load message", 0, $e);
@@ -186,7 +221,7 @@ class MailManager implements IMailManager {
 	/**
 	 * @param Account $sourceAccount
 	 * @param string $sourceFolderId
-	 * @param int $messageId
+	 * @param int $uid
 	 * @param Account $destinationAccount
 	 * @param string $destFolderId
 	 *
@@ -196,7 +231,7 @@ class MailManager implements IMailManager {
 	 */
 	public function moveMessage(Account $sourceAccount,
 								string $sourceFolderId,
-								int $messageId,
+								int $uid,
 								Account $destinationAccount,
 								string $destFolderId) {
 		if ($sourceAccount->getId() === $destinationAccount->getId()) {
@@ -204,7 +239,7 @@ class MailManager implements IMailManager {
 				$sourceAccount,
 				$sourceFolderId,
 				$destFolderId,
-				$messageId
+				$uid
 			);
 		} else {
 			throw new ServiceException('It is not possible to move across accounts yet');
@@ -237,13 +272,13 @@ class MailManager implements IMailManager {
 
 		if ($mailboxId === $trashMailbox->getName()) {
 			// Delete inside trash -> expunge
-			$this->messageMapper->expunge(
+			$this->imapMessageMapper->expunge(
 				$this->imapClientFactory->getClient($account),
 				$sourceMailbox->getName(),
 				$messageId
 			);
 		} else {
-			$this->messageMapper->move(
+			$this->imapMessageMapper->move(
 				$this->imapClientFactory->getClient($account),
 				$sourceMailbox->getName(),
 				$messageId,
@@ -273,13 +308,42 @@ class MailManager implements IMailManager {
 											  int $messageId): void {
 		$client = $this->imapClientFactory->getClient($account);
 
-		$this->messageMapper->move($client, $sourceFolderId, $messageId, $destFolderId);
+		$this->imapMessageMapper->move($client, $sourceFolderId, $messageId, $destFolderId);
 	}
 
-	public function markFolderAsRead(Account $account, string $folderId): void {
+	public function markFolderAsRead(Account $account, Mailbox $mailbox): void {
 		$client = $this->imapClientFactory->getClient($account);
 
-		$this->messageMapper->markAllRead($client, $folderId);
+		$this->imapMessageMapper->markAllRead($client, $mailbox->getName());
+	}
+
+	public function updateSubscription(Account $account, Mailbox $mailbox, bool $subscribed): Mailbox {
+		/**
+		 * 1. Change subscription on IMAP
+		 */
+		$client = $this->imapClientFactory->getClient($account);
+		try {
+			$client->subscribeMailbox($mailbox->getName(), $subscribed);
+		} catch (Horde_Imap_Client_Exception $e) {
+			throw new ServiceException("Could not set subscription status for mailbox $mailbox on IMAP: " . $e->getMessage(), $e->getCode(), $e);
+		}
+
+		/**
+		 * 2. Pull changes into the mailbox database cache
+		 */
+		$this->mailboxSync->sync($account, $this->logger,true);
+
+		/**
+		 * 3. Return the updated object
+		 */
+		return $this->mailboxMapper->find($account, $mailbox->getName());
+	}
+
+	public function enableMailboxBackgroundSync(Mailbox $mailbox,
+												bool $syncInBackground): Mailbox {
+		$mailbox->setSyncInBackground($syncInBackground);
+
+		return $this->mailboxMapper->update($mailbox);
 	}
 
 	public function flagMessage(Account $account, string $mailbox, int $uid, string $flag, bool $value): void {
@@ -295,9 +359,9 @@ class MailManager implements IMailManager {
 		try {
 			foreach ($imapFlags as $imapFlag) {
 				if ($value) {
-					$this->messageMapper->addFlag($client, $mb, $uid, $imapFlag);
+					$this->imapMessageMapper->addFlag($client, $mb, $uid, $imapFlag);
 				} else {
-					$this->messageMapper->removeFlag($client, $mb, $uid, $imapFlag);
+					$this->imapMessageMapper->removeFlag($client, $mb, $uid, $imapFlag);
 				}
 			}
 		} catch (Horde_Imap_Client_Exception $e) {
@@ -315,4 +379,92 @@ class MailManager implements IMailManager {
 			)
 		);
 	}
+
+	/**
+	 * @param Account $account
+	 *
+	 * @return Quota|null
+	 * @see https://tools.ietf.org/html/rfc2087
+	 */
+	public function getQuota(Account $account): ?Quota {
+		$client = $this->imapClientFactory->getClient($account);
+
+		/**
+		 * Get all the quotas roots of the user's mailboxes
+		 */
+		try {
+			$quotas = array_map(static function (Folder $mb) use ($client) {
+				return $client->getQuotaRoot($mb->getMailbox());
+			}, $this->folderMapper->getFolders($account, $client));
+		} catch (Horde_Imap_Client_Exception_NoSupportExtension $ex) {
+			return null;
+		}
+
+		/**
+		 * Extract the 'storage' quota
+		 *
+		 * Falls back to 0/0 if this quota has no storage information
+		 *
+		 * @see https://tools.ietf.org/html/rfc2087#section-3
+		 */
+		$storageQuotas = array_map(function (array $root) {
+			return $root['storage'] ?? [
+				'usage' => 0,
+				'limit' => 0,
+			];
+		}, array_merge(...array_values($quotas)));
+
+		if (empty($storageQuotas)) {
+			// Nothing left to do, and array_merge doesn't like to be called with zero arguments.
+			return null;
+		}
+
+		/**
+		 * Deduplicate identical quota roots
+		 */
+		$storage = array_merge(...array_values($storageQuotas));
+
+		return new Quota(
+			1024 * (int)($storage['usage'] ?? 0),
+			1024 * (int)($storage['limit'] ?? 0)
+		);
+	}
+
+	public function renameMailbox(Account $account, Mailbox $mailbox, string $name): Mailbox {
+		/*
+		 * 1. Rename on IMAP
+		 */
+		$this->folderMapper->renameFolder(
+			$this->imapClientFactory->getClient($account),
+			$mailbox->getName(),
+			$name
+		);
+
+		/**
+		 * 2. Get the IMAP changes into our database cache
+		 */
+		$this->mailboxSync->sync($account, $this->logger,true);
+
+		/**
+		 * 3. Return the cached object with the new ID
+		 */
+		try {
+			return $this->mailboxMapper->find($account, $name);
+		} catch (DoesNotExistException $e) {
+			throw new ServiceException("The renamed mailbox $name does not exist", 0, $e);
+		}
+	}
+
+	/**
+	 * @param Account $account
+	 * @param Mailbox $mailbox
+	 *
+	 * @throws ServiceException
+	 */
+	public function deleteMailbox(Account $account,
+								  Mailbox $mailbox): void {
+		$client = $this->imapClientFactory->getClient($account);
+		$this->folderMapper->delete($client, $mailbox->getName());
+		$this->mailboxMapper->delete($mailbox);
+	}
 }
