@@ -25,7 +25,6 @@ namespace OCA\Mail\Service;
 
 use Horde_Exception;
 use Horde_Imap_Client;
-use Horde_Imap_Client_Exception;
 use Horde_Mail_Transport_Null;
 use Horde_Mime_Exception;
 use Horde_Mime_Headers_Date;
@@ -39,6 +38,7 @@ use OCA\Mail\Contracts\IAttachmentService;
 use OCA\Mail\Contracts\IMailTransmission;
 use OCA\Mail\Db\Alias;
 use OCA\Mail\Db\MailboxMapper;
+use OCA\Mail\Db\Message;
 use OCA\Mail\Events\DraftSavedEvent;
 use OCA\Mail\Events\MessageSentEvent;
 use OCA\Mail\Events\SaveDraftEvent;
@@ -102,22 +102,10 @@ class MailTransmission implements IMailTransmission {
 		$this->logger = $logger;
 	}
 
-	/**
-	 * Send a new message or reply to an existing one
-	 *
-	 * @param NewMessageData $messageData
-	 * @param RepliedMessageData $replyData
-	 * @param Alias|null $alias
-	 * @param int|null $draftUID
-	 *
-	 * @throws ServiceException
-	 *
-	 * @return void
-	 */
 	public function sendMessage(NewMessageData $messageData,
 								RepliedMessageData $replyData = null,
 								Alias $alias = null,
-								int $draftUID = null) {
+								Message $draft = null) {
 		$account = $messageData->getAccount();
 
 		if ($replyData !== null) {
@@ -126,11 +114,11 @@ class MailTransmission implements IMailTransmission {
 			$message = $this->buildNewMessage($account, $messageData);
 		}
 
+		$account->setAlias($alias);
 		$fromEmail = $alias ? $alias->getAlias() : $account->getEMailAddress();
 		$from = new AddressList([
 			new Address($account->getName(), $fromEmail),
 		]);
-		$account->setAlias($alias);
 		$message->setFrom($from);
 		$message->setCC($messageData->getCc());
 		$message->setBcc($messageData->getBcc());
@@ -178,17 +166,22 @@ class MailTransmission implements IMailTransmission {
 
 		$this->eventDispatcher->dispatch(
 			MessageSentEvent::class,
-			new MessageSentEvent($account, $messageData, $replyData, $draftUID, $message, $mail)
+			new MessageSentEvent($account, $messageData, $replyData, $draft, $message, $mail)
 		);
 	}
 
 	/**
+	 * @param NewMessageData $message
+	 * @param Message|null $previousDraft
+	 *
+	 * @return array
+	 *
 	 * @throws ServiceException
 	 */
-	public function saveDraft(NewMessageData $message, int $draftUID = null): int {
+	public function saveDraft(NewMessageData $message, Message $previousDraft = null): array {
 		$this->eventDispatcher->dispatch(
 			SaveDraftEvent::class,
-			new SaveDraftEvent($message->getAccount(), $message, $draftUID)
+			new SaveDraftEvent($message->getAccount(), $message, $previousDraft)
 		);
 
 		$account = $message->getAccount();
@@ -243,10 +236,10 @@ class MailTransmission implements IMailTransmission {
 
 		$this->eventDispatcher->dispatch(
 			DraftSavedEvent::class,
-			new DraftSavedEvent($account, $message, $draftUID)
+			new DraftSavedEvent($account, $message, $previousDraft)
 		);
 
-		return $newUid;
+		return [$account, $draftsMailbox, $newUid];
 	}
 
 	private function buildReplyMessage(Account $account,
@@ -257,24 +250,8 @@ class MailTransmission implements IMailTransmission {
 		$message->setSubject($messageData->getSubject());
 		$message->setTo($messageData->getTo());
 
-		$client = $this->imapClientFactory->getClient($account);
-
-		try {
-			$repliedMessage = $this->messageMapper->find(
-				$client,
-				$replyData->getFolderId(),
-				$replyData->getId()
-			);
-
-			$message->setInReplyTo($repliedMessage->getMessageId());
-		} catch (DoesNotExistException $e) {
-			// Nothing to do
-		} catch (Horde_Imap_Client_Exception $e) {
-			$this->logger->logException($e, [
-				'level' => ILogger::WARN,
-				'messages' => 'Could not find draft message: ' . $e->getMessage(),
-			]);
-		}
+		$rawMessageId = $replyData->getMessage()->getMessageId();
+		$message->setInReplyTo($rawMessageId);
 
 		return $message;
 	}
