@@ -40,6 +40,7 @@ use OCA\Mail\IMAP\PreviewEnhancer;
 use OCA\Mail\IMAP\Search\Provider as ImapSearchProvider;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\ILogger;
+use OCP\IUser;
 
 class MailSearch implements IMailSearch {
 
@@ -75,32 +76,26 @@ class MailSearch implements IMailSearch {
 		$this->logger = $logger;
 	}
 
-	public function findMessage(Account $account, string $mailboxName, int $uid): Message {
-		try {
-			$mailbox = $this->mailboxMapper->find($account, $mailboxName);
-		} catch (DoesNotExistException $e) {
-			throw new ServiceException('Mailbox does not exist', 0, $e);
-		}
-
-		$messages = $this->previewEnhancer->process(
+	public function findMessage(Account $account,
+								Mailbox $mailbox,
+								Message $message): Message {
+		$processed = $this->previewEnhancer->process(
 			$account,
 			$mailbox,
-			$this->messageMapper->findByUids(
-				$mailbox,
-				[$uid]
-			)
+			[$message]
 		);
-		if (empty($messages)) {
+		if (empty($processed)) {
 			throw new DoesNotExistException("Message does not exist");
 		}
-		return $messages[0];
+		return $processed[0];
 	}
 
 	/**
 	 * @param Account $account
-	 * @param string $mailboxName
+	 * @param Mailbox $mailbox
 	 * @param string|null $filter
 	 * @param int|null $cursor
+	 * @param int|null $limit
 	 *
 	 * @return Message[]
 	 *
@@ -108,16 +103,10 @@ class MailSearch implements IMailSearch {
 	 * @throws ServiceException
 	 */
 	public function findMessages(Account $account,
-								 string $mailboxName,
+								 Mailbox $mailbox,
 								 ?string $filter,
 								 ?int $cursor,
 								 ?int $limit): array {
-		try {
-			$mailbox = $this->mailboxMapper->find($account, $mailboxName);
-		} catch (DoesNotExistException $e) {
-			throw new ServiceException('Mailbox does not exist', 0, $e);
-		}
-
 		if ($mailbox->hasLocks()) {
 			throw MailboxLockedException::from($mailbox);
 		}
@@ -141,21 +130,44 @@ class MailSearch implements IMailSearch {
 		return $this->previewEnhancer->process(
 			$account,
 			$mailbox,
-			$this->messageMapper->findByUids(
-				$mailbox,
-				$this->getUids($account, $mailbox, $query, $limit)
+			$this->messageMapper->findByIds(
+				$this->getIdsLocally($account, $mailbox, $query, $limit)
 			)
 		);
 	}
 
+	/**
+	 * @param IUser $user
+	 * @param string|null $filter
+	 * @param int|null $cursor
+	 *
+	 * @return Message[]
+	 *
+	 * @throws ClientException
+	 * @throws ServiceException
+	 */
+	public function findMessagesGlobally(IUser $user,
+								 ?string $filter,
+								 ?int $cursor,
+								 ?int $limit): array {
+		$query = $this->filterStringParser->parse($filter);
+		if ($cursor !== null) {
+			$query->setCursor($cursor);
+		}
+
+		return $this->messageMapper->findByIds(
+			$this->getIdsGlobally($user, $query, $limit)
+		);
+	}
+
 	/**
 	 * We combine local flag and headers merge with UIDs that match the body search if necessary
 	 *
 	 * @throws ServiceException
 	 */
-	private function getUids(Account $account, Mailbox $mailbox, SearchQuery $query, ?int $limit): array {
+	private function getIdsLocally(Account $account, Mailbox $mailbox, SearchQuery $query, ?int $limit): array {
 		if (empty($query->getTextTokens())) {
-			return $this->messageMapper->findUidsByQuery($mailbox, $query, $limit);
+			return $this->messageMapper->findIdsByQuery($mailbox, $query, $limit);
 		}
 
 		$fromImap = $this->imapSearchProvider->findMatches(
@@ -163,6 +175,17 @@ class MailSearch implements IMailSearch {
 			$mailbox,
 			$query
 		);
-		return $this->messageMapper->findUidsByQuery($mailbox, $query, $limit, $fromImap);
+		return $this->messageMapper->findIdsByQuery($mailbox, $query, $limit, $fromImap);
+	}
+
+	/**
+	 * We combine local flag and headers merge with UIDs that match the body search if necessary
+	 *
+	 * @todo find a way to search across all mailboxes efficiently without iterating over each of them and include IMAP results
+	 *
+	 * @throws ServiceException
+	 */
+	private function getIdsGlobally(IUser $user, SearchQuery $query, ?int $limit): array {
+		return $this->messageMapper->findIdsGloballyByQuery($user, $query, $limit);
 	}
 }
