@@ -31,6 +31,7 @@ use OCA\Mail\Account;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Db\MailboxMapper;
 use OCA\Mail\Db\MessageMapper as DatabaseMessageMapper;
+use OCA\Mail\Events\SynchronizationEvent;
 use OCA\Mail\Events\NewMessagesSynchronized;
 use OCA\Mail\Exception\ClientException;
 use OCA\Mail\Exception\IncompleteSyncException;
@@ -45,7 +46,7 @@ use OCA\Mail\IMAP\Sync\Synchronizer;
 use OCA\Mail\Model\IMAPMessage;
 use OCA\Mail\Support\PerformanceLogger;
 use OCP\EventDispatcher\IEventDispatcher;
-use OCP\ILogger;
+use Psr\Log\LoggerInterface;
 use Throwable;
 use function array_chunk;
 use function array_map;
@@ -79,7 +80,7 @@ class ImapToDbSynchronizer {
 	/** @var PerformanceLogger */
 	private $performanceLogger;
 
-	/** @var ILogger */
+	/** @var LoggerInterface */
 	private $logger;
 
 	public function __construct(DatabaseMessageMapper $dbMapper,
@@ -90,7 +91,7 @@ class ImapToDbSynchronizer {
 								Synchronizer $synchronizer,
 								IEventDispatcher $dispatcher,
 								PerformanceLogger $performanceLogger,
-								ILogger $logger) {
+								LoggerInterface $logger) {
 		$this->dbMapper = $dbMapper;
 		$this->clientFactory = $clientFactory;
 		$this->imapMapper = $imapMapper;
@@ -107,17 +108,31 @@ class ImapToDbSynchronizer {
 	 * @throws ServiceException
 	 */
 	public function syncAccount(Account $account,
+								LoggerInterface $logger,
 								bool $force = false,
 								int $criteria = Horde_Imap_Client::SYNC_NEWMSGSUIDS | Horde_Imap_Client::SYNC_FLAGSUIDS | Horde_Imap_Client::SYNC_VANISHEDUIDS): void {
 		foreach ($this->mailboxMapper->findAll($account) as $mailbox) {
+			if (!$mailbox->isInbox() && !$mailbox->getSyncInBackground()) {
+				$logger->debug("Skipping mailbox sync for " . $mailbox->getName());
+				continue;
+			}
+
 			$this->sync(
 				$account,
 				$mailbox,
+				$logger,
 				$criteria,
 				null,
-				$force
+				$force,
+				true
 			);
 		}
+		$this->dispatcher->dispatchTyped(
+			new SynchronizationEvent(
+				$account,
+				$logger
+			)
+		);
 	}
 
 	/**
@@ -166,17 +181,17 @@ class ImapToDbSynchronizer {
 	}
 
 	/**
-	 * @param int[] $knownUids
-	 *
 	 * @throws ClientException
 	 * @throws MailboxNotCachedException
 	 * @throws ServiceException
 	 */
 	public function sync(Account $account,
 						 Mailbox $mailbox,
+						 LoggerInterface $logger,
 						 int $criteria = Horde_Imap_Client::SYNC_NEWMSGSUIDS | Horde_Imap_Client::SYNC_FLAGSUIDS | Horde_Imap_Client::SYNC_VANISHEDUIDS,
 						 array $knownUids = null,
-						 bool $force = false): void {
+						 bool $force = false,
+						 bool $batchSync = false): void {
 		if ($mailbox->getSelectable() === false) {
 			return;
 		}
@@ -196,14 +211,14 @@ class ImapToDbSynchronizer {
 				|| $mailbox->getSyncNewToken() === null
 				|| $mailbox->getSyncChangedToken() === null
 				|| $mailbox->getSyncVanishedToken() === null) {
-				$this->runInitialSync($account, $mailbox);
+				$this->runInitialSync($account, $mailbox, $logger);
 			} else {
 				try {
-					$this->runPartialSync($account, $mailbox, $criteria, $knownUids);
+					$this->runPartialSync($account, $mailbox, $logger, $criteria, $knownUids);
 				} catch (UidValidityChangedException $e) {
-					$this->logger->warning('Mailbox UID validity changed. Wiping cache and performing full sync.');
+					$logger->warning('Mailbox UID validity changed. Wiping cache and performing full sync.');
 					$this->resetCache($account, $mailbox);
-					$this->runInitialSync($account, $mailbox);
+					$this->runInitialSync($account, $mailbox, $logger);
 				}
 			}
 		} catch (ServiceException $e) {
@@ -222,14 +237,28 @@ class ImapToDbSynchronizer {
 				$this->mailboxMapper->unlockFromNewSync($mailbox);
 			}
 		}
+
+		if (!$batchSync) {
+			$this->dispatcher->dispatchTyped(
+				new SynchronizationEvent(
+					$account,
+					$this->logger
+				)
+			);
+		}
 	}
 
 	/**
 	 * @throws ServiceException
 	 * @throws IncompleteSyncException
 	 */
-	private function runInitialSync(Account $account, Mailbox $mailbox): void {
-		$perf = $this->performanceLogger->start('Initial sync ' . $account->getId() . ':' . $mailbox->getName());
+	private function runInitialSync(Account $account,
+									Mailbox $mailbox,
+									LoggerInterface  $logger): void {
+		$perf = $this->performanceLogger->startWithLogger(
+			'Initial sync ' . $account->getId() . ':' . $mailbox->getName(),
+			$logger
+		);
 
 		$highestKnownUid = $this->dbMapper->findHighestUid($mailbox);
 		$client = $this->clientFactory->getClient($account);
@@ -278,9 +307,13 @@ class ImapToDbSynchronizer {
 	 */
 	private function runPartialSync(Account $account,
 									Mailbox $mailbox,
+									LoggerInterface $logger,
 									int $criteria,
 									array $knownUids = null): void {
-		$perf = $this->performanceLogger->start('partial sync ' . $account->getId() . ':' . $mailbox->getName());
+		$perf = $this->performanceLogger->startWithLogger(
+			'partial sync ' . $account->getId() . ':' . $mailbox->getName(),
+			$logger
+		);
 
 		$client = $this->clientFactory->getClient($account);
 		$uids = $knownUids ?? $this->dbMapper->findAllUids($mailbox);
